#[non_exhaustive]pub enum CompressionErrorKind {
UnknownCodec(i16),
CodecDisabled,
EncodeFailed {
message: String,
},
DecodeFailed {
message: String,
},
DecompressedTooLarge {
limit: usize,
},
}Expand description
Specific reason a compression operation failed.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
UnknownCodec(i16)
attributes bits 0–2 produced a value not in 0..=4.
CodecDisabled
Codec is recognised but its Cargo feature is not enabled.
EncodeFailed
Encoding (compress) failed in the underlying codec.
DecodeFailed
Decoding (decompress) failed in the underlying codec.
DecompressedTooLarge
Decompressed output exceeded the safety limit — the payload is treated as a decompression bomb rather than allowed to exhaust memory.