pub struct AddPartitionsToTxnTransaction {
pub transactional_id: KafkaString,
pub producer_id: i64,
pub producer_epoch: i16,
pub verify_only: bool,
pub topics: Vec<AddPartitionsToTxnTopic>,
pub _unknown_tagged_fields: Vec<RawTaggedField>,
}Fields
transactional_id: KafkaStringThe transactional id corresponding to the transaction.
producer_id: i64Current producer id in use by the transactional id.
producer_epoch: i16Current epoch associated with the producer id.
verify_only: boolBoolean to signify if we want to check if the partition is in the transaction rather than add it.
topics: Vec<AddPartitionsToTxnTopic>The partitions to add to the transaction.
_unknown_tagged_fields: Vec<RawTaggedField>Implementations
Sourceimpl AddPartitionsToTxnTransaction
impl AddPartitionsToTxnTransaction
pub fn with_transactional_id(self, value: KafkaString) -> Self
pub fn with_producer_id(self, value: i64) -> Self
pub fn with_producer_epoch(self, value: i16) -> Self
pub fn with_verify_only(self, value: bool) -> Self
pub fn with_topics(self, value: Vec<AddPartitionsToTxnTopic>) -> Self
pub fn read(buf: &mut Bytes, version: i16) -> Result<Self>
pub fn write(&self, buf: &mut BytesMut, version: i16) -> Result<()>
pub fn encoded_len(&self, version: i16) -> Result<usize>