pub struct AddPartitionsToTxnResponseData {
pub throttle_time_ms: i32,
pub error_code: i16,
pub results_by_transaction: Vec<AddPartitionsToTxnResult>,
pub results_by_topic_v3_and_below: Vec<AddPartitionsToTxnTopicResult>,
pub _unknown_tagged_fields: Vec<RawTaggedField>,
}Fields
throttle_time_ms: i32Duration in milliseconds for which the request was throttled due to a quota violation, or zero if the request did not violate any quota.
error_code: i16The response top level error code.
results_by_transaction: Vec<AddPartitionsToTxnResult>Results categorized by transactional ID.
results_by_topic_v3_and_below: Vec<AddPartitionsToTxnTopicResult>The results for each topic.
_unknown_tagged_fields: Vec<RawTaggedField>Implementations
Sourceimpl AddPartitionsToTxnResponseData
impl AddPartitionsToTxnResponseData
pub fn with_throttle_time_ms(self, value: i32) -> Self
pub fn with_error_code(self, value: i16) -> Self
pub fn with_results_by_transaction( self, value: Vec<AddPartitionsToTxnResult>, ) -> Self
pub fn with_results_by_topic_v3_and_below( self, value: Vec<AddPartitionsToTxnTopicResult>, ) -> Self
pub fn read(buf: &mut Bytes, version: i16) -> Result<Self>
pub fn write(&self, buf: &mut BytesMut, version: i16) -> Result<()>
pub fn encoded_len(&self, version: i16) -> Result<usize>