pub struct BrokerRegistrationRequestData {
pub broker_id: i32,
pub cluster_id: KafkaString,
pub incarnation_id: KafkaUuid,
pub listeners: Vec<Listener>,
pub features: Vec<Feature>,
pub rack: Option<KafkaString>,
pub is_migrating_zk_broker: bool,
pub log_dirs: Vec<KafkaUuid>,
pub previous_broker_epoch: i64,
pub _unknown_tagged_fields: Vec<RawTaggedField>,
}Fields
broker_id: i32The broker ID.
cluster_id: KafkaStringThe cluster id of the broker process.
incarnation_id: KafkaUuidThe incarnation id of the broker process.
listeners: Vec<Listener>The listeners of this broker.
features: Vec<Feature>The features on this broker. Note: in v0-v3, features with MinSupportedVersion = 0 are omitted.
rack: Option<KafkaString>The rack which this broker is in.
is_migrating_zk_broker: boolIf the required configurations for ZK migration are present, this value is set to true.
log_dirs: Vec<KafkaUuid>Log directories configured in this broker which are available.
previous_broker_epoch: i64The epoch before a clean shutdown.
_unknown_tagged_fields: Vec<RawTaggedField>Implementations
Sourceimpl BrokerRegistrationRequestData
impl BrokerRegistrationRequestData
pub fn with_broker_id(self, value: i32) -> Self
pub fn with_cluster_id(self, value: KafkaString) -> Self
pub fn with_incarnation_id(self, value: KafkaUuid) -> Self
pub fn with_listeners(self, value: Vec<Listener>) -> Self
pub fn with_features(self, value: Vec<Feature>) -> Self
pub fn with_rack(self, value: Option<KafkaString>) -> Self
pub fn with_is_migrating_zk_broker(self, value: bool) -> Self
pub fn with_log_dirs(self, value: Vec<KafkaUuid>) -> Self
pub fn with_previous_broker_epoch(self, value: i64) -> Self
pub fn read(buf: &mut Bytes, version: i16) -> Result<Self>
pub fn write(&self, buf: &mut BytesMut, version: i16) -> Result<()>
pub fn encoded_len(&self, version: i16) -> Result<usize>