ConsumerGroupHeartbeatRequestData

Struct ConsumerGroupHeartbeatRequestData 

pub struct ConsumerGroupHeartbeatRequestData {
    pub group_id: KafkaString,
    pub member_id: KafkaString,
    pub member_epoch: i32,
    pub instance_id: Option<KafkaString>,
    pub rack_id: Option<KafkaString>,
    pub rebalance_timeout_ms: i32,
    pub subscribed_topic_names: Option<Vec<KafkaString>>,
    pub subscribed_topic_regex: Option<KafkaString>,
    pub server_assignor: Option<KafkaString>,
    pub topic_partitions: Option<Vec<TopicPartitions>>,
    pub _unknown_tagged_fields: Vec<RawTaggedField>,
}

Fields

group_id: KafkaString

The group identifier.

member_id: KafkaString

The member id generated by the consumer. The member id must be kept during the entire lifetime of the consumer process.

member_epoch: i32

The current member epoch; 0 to join the group; -1 to leave the group; -2 to indicate that the static member will rejoin.

instance_id: Option<KafkaString>

null if not provided or if it didn’t change since the last heartbeat; the instance Id otherwise.

rack_id: Option<KafkaString>

null if not provided or if it didn’t change since the last heartbeat; the rack ID of consumer otherwise.

rebalance_timeout_ms: i32

-1 if it didn’t change since the last heartbeat; the maximum time in milliseconds that the coordinator will wait on the member to revoke its partitions otherwise.

subscribed_topic_names: Option<Vec<KafkaString>>

null if it didn’t change since the last heartbeat; the subscribed topic names otherwise.

subscribed_topic_regex: Option<KafkaString>

null if it didn’t change since the last heartbeat; the subscribed topic regex otherwise.

server_assignor: Option<KafkaString>

null if not used or if it didn’t change since the last heartbeat; the server side assignor to use otherwise.

topic_partitions: Option<Vec<TopicPartitions>>

null if it didn’t change since the last heartbeat; the partitions owned by the member.

_unknown_tagged_fields: Vec<RawTaggedField>

Implementations

Source

impl ConsumerGroupHeartbeatRequestData

pub fn with_group_id(self, value: KafkaString) -> Self

pub fn with_member_id(self, value: KafkaString) -> Self

pub fn with_member_epoch(self, value: i32) -> Self

pub fn with_instance_id(self, value: Option<KafkaString>) -> Self

pub fn with_rack_id(self, value: Option<KafkaString>) -> Self

pub fn with_rebalance_timeout_ms(self, value: i32) -> Self

pub fn with_subscribed_topic_names( self, value: Option<Vec<KafkaString>>, ) -> Self

pub fn with_subscribed_topic_regex(self, value: Option<KafkaString>) -> Self

pub fn with_server_assignor(self, value: Option<KafkaString>) -> Self

pub fn with_topic_partitions(self, value: Option<Vec<TopicPartitions>>) -> Self

pub fn read(buf: &mut Bytes, version: i16) -> Result<Self>

pub fn write(&self, buf: &mut BytesMut, version: i16) -> Result<()>

pub fn encoded_len(&self, version: i16) -> Result<usize>