pub struct CreateDelegationTokenRequestData {
pub owner_principal_type: Option<KafkaString>,
pub owner_principal_name: Option<KafkaString>,
pub renewers: Vec<CreatableRenewers>,
pub max_lifetime_ms: i64,
pub _unknown_tagged_fields: Vec<RawTaggedField>,
}Fields
owner_principal_type: Option<KafkaString>The principal type of the owner of the token. If it’s null it defaults to the token request principal.
owner_principal_name: Option<KafkaString>The principal name of the owner of the token. If it’s null it defaults to the token request principal.
renewers: Vec<CreatableRenewers>A list of those who are allowed to renew this token before it expires.
max_lifetime_ms: i64The maximum lifetime of the token in milliseconds, or -1 to use the server side default.
_unknown_tagged_fields: Vec<RawTaggedField>Implementations
Sourceimpl CreateDelegationTokenRequestData
impl CreateDelegationTokenRequestData
pub fn with_owner_principal_type(self, value: Option<KafkaString>) -> Self
pub fn with_owner_principal_name(self, value: Option<KafkaString>) -> Self
pub fn with_renewers(self, value: Vec<CreatableRenewers>) -> Self
pub fn with_max_lifetime_ms(self, value: i64) -> Self
pub fn read(buf: &mut Bytes, version: i16) -> Result<Self>
pub fn write(&self, buf: &mut BytesMut, version: i16) -> Result<()>
pub fn encoded_len(&self, version: i16) -> Result<usize>