pub struct CreateDelegationTokenResponseData {
pub error_code: i16,
pub principal_type: KafkaString,
pub principal_name: KafkaString,
pub token_requester_principal_type: KafkaString,
pub token_requester_principal_name: KafkaString,
pub issue_timestamp_ms: i64,
pub expiry_timestamp_ms: i64,
pub max_timestamp_ms: i64,
pub token_id: KafkaString,
pub hmac: Bytes,
pub throttle_time_ms: i32,
pub _unknown_tagged_fields: Vec<RawTaggedField>,
}Fields
error_code: i16The top-level error, or zero if there was no error.
principal_type: KafkaStringThe principal type of the token owner.
principal_name: KafkaStringThe name of the token owner.
token_requester_principal_type: KafkaStringThe principal type of the requester of the token.
token_requester_principal_name: KafkaStringThe principal type of the requester of the token.
issue_timestamp_ms: i64When this token was generated.
expiry_timestamp_ms: i64When this token expires.
max_timestamp_ms: i64The maximum lifetime of this token.
token_id: KafkaStringThe token UUID.
hmac: BytesHMAC of the delegation token.
throttle_time_ms: i32The duration in milliseconds for which the request was throttled due to a quota violation, or zero if the request did not violate any quota.
_unknown_tagged_fields: Vec<RawTaggedField>Implementations
Sourceimpl CreateDelegationTokenResponseData
impl CreateDelegationTokenResponseData
pub fn with_error_code(self, value: i16) -> Self
pub fn with_principal_type(self, value: KafkaString) -> Self
pub fn with_principal_name(self, value: KafkaString) -> Self
pub fn with_token_requester_principal_type(self, value: KafkaString) -> Self
pub fn with_token_requester_principal_name(self, value: KafkaString) -> Self
pub fn with_issue_timestamp_ms(self, value: i64) -> Self
pub fn with_expiry_timestamp_ms(self, value: i64) -> Self
pub fn with_max_timestamp_ms(self, value: i64) -> Self
pub fn with_token_id(self, value: KafkaString) -> Self
pub fn with_hmac(self, value: Bytes) -> Self
pub fn with_throttle_time_ms(self, value: i32) -> Self
pub fn read(buf: &mut Bytes, version: i16) -> Result<Self>
pub fn write(&self, buf: &mut BytesMut, version: i16) -> Result<()>
pub fn encoded_len(&self, version: i16) -> Result<usize>