pub struct CreatePartitionsRequestData {
pub topics: Vec<CreatePartitionsTopic>,
pub timeout_ms: i32,
pub validate_only: bool,
pub _unknown_tagged_fields: Vec<RawTaggedField>,
}Fields
topics: Vec<CreatePartitionsTopic>Each topic that we want to create new partitions inside.
timeout_ms: i32The time in ms to wait for the partitions to be created.
validate_only: boolIf true, then validate the request, but don’t actually increase the number of partitions.
_unknown_tagged_fields: Vec<RawTaggedField>Implementations
Sourceimpl CreatePartitionsRequestData
impl CreatePartitionsRequestData
pub fn with_topics(self, value: Vec<CreatePartitionsTopic>) -> Self
pub fn with_timeout_ms(self, value: i32) -> Self
pub fn with_validate_only(self, value: bool) -> Self
pub fn read(buf: &mut Bytes, version: i16) -> Result<Self>
pub fn write(&self, buf: &mut BytesMut, version: i16) -> Result<()>
pub fn encoded_len(&self, version: i16) -> Result<usize>