pub struct CreatePartitionsResponseData {
pub throttle_time_ms: i32,
pub results: Vec<CreatePartitionsTopicResult>,
pub _unknown_tagged_fields: Vec<RawTaggedField>,
}Fields
throttle_time_ms: i32The duration in milliseconds for which the request was throttled due to a quota violation, or zero if the request did not violate any quota.
results: Vec<CreatePartitionsTopicResult>The partition creation results for each topic.
_unknown_tagged_fields: Vec<RawTaggedField>Implementations
Sourceimpl CreatePartitionsResponseData
impl CreatePartitionsResponseData
pub fn with_throttle_time_ms(self, value: i32) -> Self
pub fn with_results(self, value: Vec<CreatePartitionsTopicResult>) -> Self
pub fn read(buf: &mut Bytes, version: i16) -> Result<Self>
pub fn write(&self, buf: &mut BytesMut, version: i16) -> Result<()>
pub fn encoded_len(&self, version: i16) -> Result<usize>