pub struct CreatableTopic {
pub name: KafkaString,
pub num_partitions: i32,
pub replication_factor: i16,
pub assignments: Vec<CreatableReplicaAssignment>,
pub configs: Vec<CreatableTopicConfig>,
pub _unknown_tagged_fields: Vec<RawTaggedField>,
}Fields
name: KafkaStringThe topic name.
num_partitions: i32The number of partitions to create in the topic, or -1 if we are either specifying a manual partition assignment or using the default partitions.
replication_factor: i16The number of replicas to create for each partition in the topic, or -1 if we are either specifying a manual partition assignment or using the default replication factor.
assignments: Vec<CreatableReplicaAssignment>The manual partition assignment, or the empty array if we are using automatic assignment.
configs: Vec<CreatableTopicConfig>The custom topic configurations to set.
_unknown_tagged_fields: Vec<RawTaggedField>Implementations
Sourceimpl CreatableTopic
impl CreatableTopic
pub fn with_name(self, value: KafkaString) -> Self
pub fn with_num_partitions(self, value: i32) -> Self
pub fn with_replication_factor(self, value: i16) -> Self
pub fn with_assignments(self, value: Vec<CreatableReplicaAssignment>) -> Self
pub fn with_configs(self, value: Vec<CreatableTopicConfig>) -> Self
pub fn read(buf: &mut Bytes, version: i16) -> Result<Self>
pub fn write(&self, buf: &mut BytesMut, version: i16) -> Result<()>
pub fn encoded_len(&self, version: i16) -> Result<usize>