pub struct CreateTopicsRequestData {
pub topics: Vec<CreatableTopic>,
pub timeout_ms: i32,
pub validate_only: bool,
pub _unknown_tagged_fields: Vec<RawTaggedField>,
}Fields
topics: Vec<CreatableTopic>The topics to create.
timeout_ms: i32How long to wait in milliseconds before timing out the request.
validate_only: boolIf true, check that the topics can be created as specified, but don’t create anything.
_unknown_tagged_fields: Vec<RawTaggedField>Implementations
Sourceimpl CreateTopicsRequestData
impl CreateTopicsRequestData
pub fn with_topics(self, value: Vec<CreatableTopic>) -> Self
pub fn with_timeout_ms(self, value: i32) -> Self
pub fn with_validate_only(self, value: bool) -> Self
pub fn read(buf: &mut Bytes, version: i16) -> Result<Self>
pub fn write(&self, buf: &mut BytesMut, version: i16) -> Result<()>
pub fn encoded_len(&self, version: i16) -> Result<usize>