pub struct CreatableTopicResult {
pub name: KafkaString,
pub topic_id: KafkaUuid,
pub error_code: i16,
pub error_message: Option<KafkaString>,
pub topic_config_error_code: i16,
pub num_partitions: i32,
pub replication_factor: i16,
pub configs: Option<Vec<CreatableTopicConfigs>>,
pub _unknown_tagged_fields: Vec<RawTaggedField>,
}Fields
name: KafkaStringThe topic name.
topic_id: KafkaUuidThe unique topic ID.
error_code: i16The error code, or 0 if there was no error.
error_message: Option<KafkaString>The error message, or null if there was no error.
topic_config_error_code: i16Optional topic config error returned if configs are not returned in the response.
num_partitions: i32Number of partitions of the topic.
replication_factor: i16Replication factor of the topic.
configs: Option<Vec<CreatableTopicConfigs>>Configuration of the topic.
_unknown_tagged_fields: Vec<RawTaggedField>Implementations
Sourceimpl CreatableTopicResult
impl CreatableTopicResult
pub fn with_name(self, value: KafkaString) -> Self
pub fn with_topic_id(self, value: KafkaUuid) -> Self
pub fn with_error_code(self, value: i16) -> Self
pub fn with_error_message(self, value: Option<KafkaString>) -> Self
pub fn with_topic_config_error_code(self, value: i16) -> Self
pub fn with_num_partitions(self, value: i32) -> Self
pub fn with_replication_factor(self, value: i16) -> Self
pub fn with_configs(self, value: Option<Vec<CreatableTopicConfigs>>) -> Self
pub fn read(buf: &mut Bytes, version: i16) -> Result<Self>
pub fn write(&self, buf: &mut BytesMut, version: i16) -> Result<()>
pub fn encoded_len(&self, version: i16) -> Result<usize>