pub struct DeleteRecordsResponseData {
pub throttle_time_ms: i32,
pub topics: Vec<DeleteRecordsTopicResult>,
pub _unknown_tagged_fields: Vec<RawTaggedField>,
}Fields
throttle_time_ms: i32The duration in milliseconds for which the request was throttled due to a quota violation, or zero if the request did not violate any quota.
topics: Vec<DeleteRecordsTopicResult>Each topic that we wanted to delete records from.
_unknown_tagged_fields: Vec<RawTaggedField>Implementations
Sourceimpl DeleteRecordsResponseData
impl DeleteRecordsResponseData
pub fn with_throttle_time_ms(self, value: i32) -> Self
pub fn with_topics(self, value: Vec<DeleteRecordsTopicResult>) -> Self
pub fn read(buf: &mut Bytes, version: i16) -> Result<Self>
pub fn write(&self, buf: &mut BytesMut, version: i16) -> Result<()>
pub fn encoded_len(&self, version: i16) -> Result<usize>