pub struct DeleteTopicsResponseData {
pub throttle_time_ms: i32,
pub responses: Vec<DeletableTopicResult>,
pub _unknown_tagged_fields: Vec<RawTaggedField>,
}Fields
throttle_time_ms: i32The duration in milliseconds for which the request was throttled due to a quota violation, or zero if the request did not violate any quota.
responses: Vec<DeletableTopicResult>The results for each topic we tried to delete.
_unknown_tagged_fields: Vec<RawTaggedField>Implementations
Sourceimpl DeleteTopicsResponseData
impl DeleteTopicsResponseData
pub fn with_throttle_time_ms(self, value: i32) -> Self
pub fn with_responses(self, value: Vec<DeletableTopicResult>) -> Self
pub fn read(buf: &mut Bytes, version: i16) -> Result<Self>
pub fn write(&self, buf: &mut BytesMut, version: i16) -> Result<()>
pub fn encoded_len(&self, version: i16) -> Result<usize>