pub struct ComponentData {
pub entity_type: KafkaString,
pub match_type: i8,
pub match: Option<KafkaString>,
pub _unknown_tagged_fields: Vec<RawTaggedField>,
}Fields
entity_type: KafkaStringThe entity type that the filter component applies to.
match_type: i8How to match the entity {0 = exact name, 1 = default name, 2 = any specified name}.
match: Option<KafkaString>The string to match against, or null if unused for the match type.
_unknown_tagged_fields: Vec<RawTaggedField>Implementations
Sourceimpl ComponentData
impl ComponentData
pub fn with_entity_type(self, value: KafkaString) -> Self
pub fn with_match_type(self, value: i8) -> Self
pub fn with_match(self, value: Option<KafkaString>) -> Self
pub fn read(buf: &mut Bytes, version: i16) -> Result<Self>
pub fn write(&self, buf: &mut BytesMut, version: i16) -> Result<()>
pub fn encoded_len(&self, version: i16) -> Result<usize>