pub struct DescribeLogDirsResponseData {
pub throttle_time_ms: i32,
pub error_code: i16,
pub results: Vec<DescribeLogDirsResult>,
pub _unknown_tagged_fields: Vec<RawTaggedField>,
}Fields
throttle_time_ms: i32The duration in milliseconds for which the request was throttled due to a quota violation, or zero if the request did not violate any quota.
error_code: i16The error code, or 0 if there was no error.
results: Vec<DescribeLogDirsResult>The log directories.
_unknown_tagged_fields: Vec<RawTaggedField>Implementations
Sourceimpl DescribeLogDirsResponseData
impl DescribeLogDirsResponseData
pub fn with_throttle_time_ms(self, value: i32) -> Self
pub fn with_error_code(self, value: i16) -> Self
pub fn with_results(self, value: Vec<DescribeLogDirsResult>) -> Self
pub fn read(buf: &mut Bytes, version: i16) -> Result<Self>
pub fn write(&self, buf: &mut BytesMut, version: i16) -> Result<()>
pub fn encoded_len(&self, version: i16) -> Result<usize>