ReplicaState

Struct ReplicaState 

pub struct ReplicaState {
    pub replica_id: i32,
    pub replica_directory_id: KafkaUuid,
    pub log_end_offset: i64,
    pub last_fetch_timestamp: i64,
    pub last_caught_up_timestamp: i64,
    pub _unknown_tagged_fields: Vec<RawTaggedField>,
}

Fields

replica_id: i32

The ID of the replica.

replica_directory_id: KafkaUuid

The replica directory ID of the replica.

log_end_offset: i64

The last known log end offset of the follower or -1 if it is unknown.

last_fetch_timestamp: i64

The last known leader wall clock time time when a follower fetched from the leader. This is reported as -1 both for the current leader or if it is unknown for a voter.

last_caught_up_timestamp: i64

The leader wall clock append time of the offset for which the follower made the most recent fetch request. This is reported as the current time for the leader and -1 if unknown for a voter.

_unknown_tagged_fields: Vec<RawTaggedField>

Implementations

Source

impl ReplicaState

pub fn with_replica_id(self, value: i32) -> Self

pub fn with_replica_directory_id(self, value: KafkaUuid) -> Self

pub fn with_log_end_offset(self, value: i64) -> Self

pub fn with_last_fetch_timestamp(self, value: i64) -> Self

pub fn with_last_caught_up_timestamp(self, value: i64) -> Self

pub fn read(buf: &mut Bytes, version: i16) -> Result<Self>

pub fn write(&self, buf: &mut BytesMut, version: i16) -> Result<()>

pub fn encoded_len(&self, version: i16) -> Result<usize>