pub struct DescribeTopicPartitionsResponsePartition {
pub error_code: i16,
pub partition_index: i32,
pub leader_id: i32,
pub leader_epoch: i32,
pub replica_nodes: Vec<i32>,
pub isr_nodes: Vec<i32>,
pub eligible_leader_replicas: Option<Vec<i32>>,
pub last_known_elr: Option<Vec<i32>>,
pub offline_replicas: Vec<i32>,
pub _unknown_tagged_fields: Vec<RawTaggedField>,
}Fields
error_code: i16The partition error, or 0 if there was no error.
partition_index: i32The partition index.
leader_id: i32The ID of the leader broker.
leader_epoch: i32The leader epoch of this partition.
replica_nodes: Vec<i32>The set of all nodes that host this partition.
isr_nodes: Vec<i32>The set of nodes that are in sync with the leader for this partition.
eligible_leader_replicas: Option<Vec<i32>>The new eligible leader replicas otherwise.
last_known_elr: Option<Vec<i32>>The last known ELR.
offline_replicas: Vec<i32>The set of offline replicas of this partition.
_unknown_tagged_fields: Vec<RawTaggedField>Implementations
Sourceimpl DescribeTopicPartitionsResponsePartition
impl DescribeTopicPartitionsResponsePartition
pub fn with_error_code(self, value: i16) -> Self
pub fn with_partition_index(self, value: i32) -> Self
pub fn with_leader_id(self, value: i32) -> Self
pub fn with_leader_epoch(self, value: i32) -> Self
pub fn with_replica_nodes(self, value: Vec<i32>) -> Self
pub fn with_isr_nodes(self, value: Vec<i32>) -> Self
pub fn with_eligible_leader_replicas(self, value: Option<Vec<i32>>) -> Self
pub fn with_last_known_elr(self, value: Option<Vec<i32>>) -> Self
pub fn with_offline_replicas(self, value: Vec<i32>) -> Self
pub fn read(buf: &mut Bytes, _version: i16) -> Result<Self>
pub fn write(&self, buf: &mut BytesMut, _version: i16) -> Result<()>
pub fn encoded_len(&self, _version: i16) -> Result<usize>