pub struct DescribeTransactionsResponseData {
pub throttle_time_ms: i32,
pub transaction_states: Vec<TransactionState>,
pub _unknown_tagged_fields: Vec<RawTaggedField>,
}Fields
throttle_time_ms: i32The duration in milliseconds for which the request was throttled due to a quota violation, or zero if the request did not violate any quota.
transaction_states: Vec<TransactionState>The current state of the transaction.
_unknown_tagged_fields: Vec<RawTaggedField>Implementations
Sourceimpl DescribeTransactionsResponseData
impl DescribeTransactionsResponseData
pub fn with_throttle_time_ms(self, value: i32) -> Self
pub fn with_transaction_states(self, value: Vec<TransactionState>) -> Self
pub fn read(buf: &mut Bytes, version: i16) -> Result<Self>
pub fn write(&self, buf: &mut BytesMut, version: i16) -> Result<()>
pub fn encoded_len(&self, version: i16) -> Result<usize>