pub struct TransactionState {
pub error_code: i16,
pub transactional_id: KafkaString,
pub transaction_state: KafkaString,
pub transaction_timeout_ms: i32,
pub transaction_start_time_ms: i64,
pub producer_id: i64,
pub producer_epoch: i16,
pub topics: Vec<TopicData>,
pub _unknown_tagged_fields: Vec<RawTaggedField>,
}Fields
error_code: i16The error code.
transactional_id: KafkaStringThe transactional id.
transaction_state: KafkaStringThe current transaction state of the producer.
transaction_timeout_ms: i32The timeout in milliseconds for the transaction.
transaction_start_time_ms: i64The start time of the transaction in milliseconds.
producer_id: i64The current producer id associated with the transaction.
producer_epoch: i16The current epoch associated with the producer id.
topics: Vec<TopicData>The set of partitions included in the current transaction (if active). When a transaction is preparing to commit or abort, this will include only partitions which do not have markers.
_unknown_tagged_fields: Vec<RawTaggedField>Implementations
Sourceimpl TransactionState
impl TransactionState
pub fn with_error_code(self, value: i16) -> Self
pub fn with_transactional_id(self, value: KafkaString) -> Self
pub fn with_transaction_state(self, value: KafkaString) -> Self
pub fn with_transaction_timeout_ms(self, value: i32) -> Self
pub fn with_transaction_start_time_ms(self, value: i64) -> Self
pub fn with_producer_id(self, value: i64) -> Self
pub fn with_producer_epoch(self, value: i16) -> Self
pub fn with_topics(self, value: Vec<TopicData>) -> Self
pub fn read(buf: &mut Bytes, version: i16) -> Result<Self>
pub fn write(&self, buf: &mut BytesMut, version: i16) -> Result<()>
pub fn encoded_len(&self, version: i16) -> Result<usize>