pub struct ElectLeadersResponseData {
pub throttle_time_ms: i32,
pub error_code: i16,
pub replica_election_results: Vec<ReplicaElectionResult>,
pub _unknown_tagged_fields: Vec<RawTaggedField>,
}Fields
throttle_time_ms: i32The duration in milliseconds for which the request was throttled due to a quota violation, or zero if the request did not violate any quota.
error_code: i16The top level response error code.
replica_election_results: Vec<ReplicaElectionResult>The election results, or an empty array if the requester did not have permission and the request asks for all partitions.
_unknown_tagged_fields: Vec<RawTaggedField>Implementations
Sourceimpl ElectLeadersResponseData
impl ElectLeadersResponseData
pub fn with_throttle_time_ms(self, value: i32) -> Self
pub fn with_error_code(self, value: i16) -> Self
pub fn with_replica_election_results( self, value: Vec<ReplicaElectionResult>, ) -> Self
pub fn read(buf: &mut Bytes, version: i16) -> Result<Self>
pub fn write(&self, buf: &mut BytesMut, version: i16) -> Result<()>
pub fn encoded_len(&self, version: i16) -> Result<usize>