pub struct PartitionResult {
pub partition_id: i32,
pub error_code: i16,
pub error_message: Option<KafkaString>,
pub _unknown_tagged_fields: Vec<RawTaggedField>,
}Fields
partition_id: i32The partition id.
error_code: i16The result error, or zero if there was no error.
error_message: Option<KafkaString>The result message, or null if there was no error.
_unknown_tagged_fields: Vec<RawTaggedField>Implementations
Sourceimpl PartitionResult
impl PartitionResult
pub fn with_partition_id(self, value: i32) -> Self
pub fn with_error_code(self, value: i16) -> Self
pub fn with_error_message(self, value: Option<KafkaString>) -> Self
pub fn read(buf: &mut Bytes, version: i16) -> Result<Self>
pub fn write(&self, buf: &mut BytesMut, version: i16) -> Result<()>
pub fn encoded_len(&self, version: i16) -> Result<usize>