pub struct PartitionData {
pub partition_index: i32,
pub leader_id: i32,
pub leader_epoch: i32,
pub preferred_successors: Vec<i32>,
pub preferred_candidates: Vec<ReplicaInfo>,
pub _unknown_tagged_fields: Vec<RawTaggedField>,
}Fields
partition_index: i32The partition index.
leader_id: i32The current leader ID that is resigning.
leader_epoch: i32The current epoch.
preferred_successors: Vec<i32>A sorted list of preferred successors to start the election.
preferred_candidates: Vec<ReplicaInfo>A sorted list of preferred candidates to start the election.
_unknown_tagged_fields: Vec<RawTaggedField>Implementations
Sourceimpl PartitionData
impl PartitionData
pub fn with_partition_index(self, value: i32) -> Self
pub fn with_leader_id(self, value: i32) -> Self
pub fn with_leader_epoch(self, value: i32) -> Self
pub fn with_preferred_successors(self, value: Vec<i32>) -> Self
pub fn with_preferred_candidates(self, value: Vec<ReplicaInfo>) -> Self
pub fn read(buf: &mut Bytes, version: i16) -> Result<Self>
pub fn write(&self, buf: &mut BytesMut, version: i16) -> Result<()>
pub fn encoded_len(&self, version: i16) -> Result<usize>