pub struct FetchPartition {
pub partition: i32,
pub current_leader_epoch: i32,
pub fetch_offset: i64,
pub last_fetched_epoch: i32,
pub log_start_offset: i64,
pub partition_max_bytes: i32,
pub replica_directory_id: KafkaUuid,
pub high_watermark: i64,
pub _unknown_tagged_fields: Vec<RawTaggedField>,
}Fields
partition: i32The partition index.
current_leader_epoch: i32The current leader epoch of the partition.
fetch_offset: i64The message offset.
last_fetched_epoch: i32The epoch of the last fetched record or -1 if there is none.
log_start_offset: i64The earliest available offset of the follower replica. The field is only used when the request is sent by the follower.
partition_max_bytes: i32The maximum bytes to fetch from this partition. See KIP-74 for cases where this limit may not be honored.
replica_directory_id: KafkaUuidThe directory id of the follower fetching.
high_watermark: i64The high-watermark known by the replica. -1 if the high-watermark is not known and 9223372036854775807 if the feature is not supported.
_unknown_tagged_fields: Vec<RawTaggedField>Implementations
Sourceimpl FetchPartition
impl FetchPartition
pub fn with_partition(self, value: i32) -> Self
pub fn with_current_leader_epoch(self, value: i32) -> Self
pub fn with_fetch_offset(self, value: i64) -> Self
pub fn with_last_fetched_epoch(self, value: i32) -> Self
pub fn with_log_start_offset(self, value: i64) -> Self
pub fn with_partition_max_bytes(self, value: i32) -> Self
pub fn with_replica_directory_id(self, value: KafkaUuid) -> Self
pub fn with_high_watermark(self, value: i64) -> Self
pub fn read(buf: &mut Bytes, version: i16) -> Result<Self>
pub fn write(&self, buf: &mut BytesMut, version: i16) -> Result<()>
pub fn encoded_len(&self, version: i16) -> Result<usize>