PartitionData

Struct PartitionData 

pub struct PartitionData {
    pub partition_index: i32,
    pub error_code: i16,
    pub high_watermark: i64,
    pub last_stable_offset: i64,
    pub log_start_offset: i64,
    pub diverging_epoch: EpochEndOffset,
    pub current_leader: LeaderIdAndEpoch,
    pub snapshot_id: SnapshotId,
    pub aborted_transactions: Option<Vec<AbortedTransaction>>,
    pub preferred_read_replica: i32,
    pub records: Option<Bytes>,
    pub _unknown_tagged_fields: Vec<RawTaggedField>,
}

Fields

partition_index: i32

The partition index.

error_code: i16

The error code, or 0 if there was no fetch error.

high_watermark: i64

The current high water mark.

last_stable_offset: i64

The last stable offset (or LSO) of the partition. This is the last offset such that the state of all transactional records prior to this offset have been decided (ABORTED or COMMITTED).

log_start_offset: i64

The current log start offset.

diverging_epoch: EpochEndOffset

In case divergence is detected based on the LastFetchedEpoch and FetchOffset in the request, this field indicates the largest epoch and its end offset such that subsequent records are known to diverge.

current_leader: LeaderIdAndEpoch

The current leader of the partition.

snapshot_id: SnapshotId

In the case of fetching an offset less than the LogStartOffset, this is the end offset and epoch that should be used in the FetchSnapshot request.

aborted_transactions: Option<Vec<AbortedTransaction>>

The aborted transactions.

preferred_read_replica: i32

The preferred read replica for the consumer to use on its next fetch request.

records: Option<Bytes>

The record data.

_unknown_tagged_fields: Vec<RawTaggedField>

Implementations

Source

impl PartitionData

pub fn with_partition_index(self, value: i32) -> Self

pub fn with_error_code(self, value: i16) -> Self

pub fn with_high_watermark(self, value: i64) -> Self

pub fn with_last_stable_offset(self, value: i64) -> Self

pub fn with_log_start_offset(self, value: i64) -> Self

pub fn with_diverging_epoch(self, value: EpochEndOffset) -> Self

pub fn with_current_leader(self, value: LeaderIdAndEpoch) -> Self

pub fn with_snapshot_id(self, value: SnapshotId) -> Self

pub fn with_aborted_transactions( self, value: Option<Vec<AbortedTransaction>>, ) -> Self

pub fn with_preferred_read_replica(self, value: i32) -> Self

pub fn with_records(self, value: Option<Bytes>) -> Self

pub fn read(buf: &mut Bytes, version: i16) -> Result<Self>

pub fn write(&self, buf: &mut BytesMut, version: i16) -> Result<()>

pub fn encoded_len(&self, version: i16) -> Result<usize>