pub struct FetchSnapshotRequestData {
pub cluster_id: Option<KafkaString>,
pub replica_id: i32,
pub max_bytes: i32,
pub topics: Vec<TopicSnapshot>,
pub _unknown_tagged_fields: Vec<RawTaggedField>,
}Fields
cluster_id: Option<KafkaString>The clusterId if known, this is used to validate metadata fetches prior to broker registration.
replica_id: i32The broker ID of the follower.
max_bytes: i32The maximum bytes to fetch from all of the snapshots.
topics: Vec<TopicSnapshot>The topics to fetch.
_unknown_tagged_fields: Vec<RawTaggedField>Implementations
Sourceimpl FetchSnapshotRequestData
impl FetchSnapshotRequestData
pub fn with_cluster_id(self, value: Option<KafkaString>) -> Self
pub fn with_replica_id(self, value: i32) -> Self
pub fn with_max_bytes(self, value: i32) -> Self
pub fn with_topics(self, value: Vec<TopicSnapshot>) -> Self
pub fn read(buf: &mut Bytes, version: i16) -> Result<Self>
pub fn write(&self, buf: &mut BytesMut, version: i16) -> Result<()>
pub fn encoded_len(&self, version: i16) -> Result<usize>