pub struct FetchSnapshotResponseData {
pub throttle_time_ms: i32,
pub error_code: i16,
pub topics: Vec<TopicSnapshot>,
pub node_endpoints: Vec<NodeEndpoint>,
pub _unknown_tagged_fields: Vec<RawTaggedField>,
}Fields
throttle_time_ms: i32The duration in milliseconds for which the request was throttled due to a quota violation, or zero if the request did not violate any quota.
error_code: i16The top level response error code.
topics: Vec<TopicSnapshot>The topics to fetch.
node_endpoints: Vec<NodeEndpoint>Endpoints for all current-leaders enumerated in PartitionSnapshot.
_unknown_tagged_fields: Vec<RawTaggedField>Implementations
Sourceimpl FetchSnapshotResponseData
impl FetchSnapshotResponseData
pub fn with_throttle_time_ms(self, value: i32) -> Self
pub fn with_error_code(self, value: i16) -> Self
pub fn with_topics(self, value: Vec<TopicSnapshot>) -> Self
pub fn with_node_endpoints(self, value: Vec<NodeEndpoint>) -> Self
pub fn read(buf: &mut Bytes, version: i16) -> Result<Self>
pub fn write(&self, buf: &mut BytesMut, version: i16) -> Result<()>
pub fn encoded_len(&self, version: i16) -> Result<usize>