pub struct GetTelemetrySubscriptionsResponseData {
pub throttle_time_ms: i32,
pub error_code: i16,
pub client_instance_id: KafkaUuid,
pub subscription_id: i32,
pub accepted_compression_types: Vec<i8>,
pub push_interval_ms: i32,
pub telemetry_max_bytes: i32,
pub delta_temporality: bool,
pub requested_metrics: Vec<KafkaString>,
pub _unknown_tagged_fields: Vec<RawTaggedField>,
}Fields
throttle_time_ms: i32The duration in milliseconds for which the request was throttled due to a quota violation, or zero if the request did not violate any quota.
error_code: i16The error code, or 0 if there was no error.
client_instance_id: KafkaUuidAssigned client instance id if ClientInstanceId was 0 in the request, else 0.
subscription_id: i32Unique identifier for the current subscription set for this client instance.
accepted_compression_types: Vec<i8>Compression types that broker accepts for the PushTelemetryRequest.
push_interval_ms: i32Configured push interval, which is the lowest configured interval in the current subscription set.
telemetry_max_bytes: i32The maximum bytes of binary data the broker accepts in PushTelemetryRequest.
delta_temporality: boolFlag to indicate monotonic/counter metrics are to be emitted as deltas or cumulative values.
requested_metrics: Vec<KafkaString>Requested metrics prefix string match. Empty array: No metrics subscribed, Array[0] empty string: All metrics subscribed.
_unknown_tagged_fields: Vec<RawTaggedField>Implementations
Sourceimpl GetTelemetrySubscriptionsResponseData
impl GetTelemetrySubscriptionsResponseData
pub fn with_throttle_time_ms(self, value: i32) -> Self
pub fn with_error_code(self, value: i16) -> Self
pub fn with_client_instance_id(self, value: KafkaUuid) -> Self
pub fn with_subscription_id(self, value: i32) -> Self
pub fn with_accepted_compression_types(self, value: Vec<i8>) -> Self
pub fn with_push_interval_ms(self, value: i32) -> Self
pub fn with_telemetry_max_bytes(self, value: i32) -> Self
pub fn with_delta_temporality(self, value: bool) -> Self
pub fn with_requested_metrics(self, value: Vec<KafkaString>) -> Self
pub fn read(buf: &mut Bytes, version: i16) -> Result<Self>
pub fn write(&self, buf: &mut BytesMut, version: i16) -> Result<()>
pub fn encoded_len(&self, version: i16) -> Result<usize>