pub struct JoinGroupResponseData {
pub throttle_time_ms: i32,
pub error_code: i16,
pub generation_id: i32,
pub protocol_type: Option<KafkaString>,
pub protocol_name: Option<KafkaString>,
pub leader: KafkaString,
pub skip_assignment: bool,
pub member_id: KafkaString,
pub members: Vec<JoinGroupResponseMember>,
pub _unknown_tagged_fields: Vec<RawTaggedField>,
}Fields
throttle_time_ms: i32The duration in milliseconds for which the request was throttled due to a quota violation, or zero if the request did not violate any quota.
error_code: i16The error code, or 0 if there was no error.
generation_id: i32The generation ID of the group.
protocol_type: Option<KafkaString>The group protocol name.
protocol_name: Option<KafkaString>The group protocol selected by the coordinator.
leader: KafkaStringThe leader of the group.
skip_assignment: boolTrue if the leader must skip running the assignment.
member_id: KafkaStringThe member ID assigned by the group coordinator.
members: Vec<JoinGroupResponseMember>The group members.
_unknown_tagged_fields: Vec<RawTaggedField>Implementations
Sourceimpl JoinGroupResponseData
impl JoinGroupResponseData
pub fn with_throttle_time_ms(self, value: i32) -> Self
pub fn with_error_code(self, value: i16) -> Self
pub fn with_generation_id(self, value: i32) -> Self
pub fn with_protocol_type(self, value: Option<KafkaString>) -> Self
pub fn with_protocol_name(self, value: Option<KafkaString>) -> Self
pub fn with_leader(self, value: KafkaString) -> Self
pub fn with_skip_assignment(self, value: bool) -> Self
pub fn with_member_id(self, value: KafkaString) -> Self
pub fn with_members(self, value: Vec<JoinGroupResponseMember>) -> Self
pub fn read(buf: &mut Bytes, version: i16) -> Result<Self>
pub fn write(&self, buf: &mut BytesMut, version: i16) -> Result<()>
pub fn encoded_len(&self, version: i16) -> Result<usize>