pub struct ListGroupsRequestData {
pub states_filter: Vec<KafkaString>,
pub types_filter: Vec<KafkaString>,
pub _unknown_tagged_fields: Vec<RawTaggedField>,
}Fields
states_filter: Vec<KafkaString>The states of the groups we want to list. If empty, all groups are returned with their state.
types_filter: Vec<KafkaString>The types of the groups we want to list. If empty, all groups are returned with their type.
_unknown_tagged_fields: Vec<RawTaggedField>Implementations
Sourceimpl ListGroupsRequestData
impl ListGroupsRequestData
pub fn with_states_filter(self, value: Vec<KafkaString>) -> Self
pub fn with_types_filter(self, value: Vec<KafkaString>) -> Self
pub fn read(buf: &mut Bytes, version: i16) -> Result<Self>
pub fn write(&self, buf: &mut BytesMut, version: i16) -> Result<()>
pub fn encoded_len(&self, version: i16) -> Result<usize>