ListOffsetsRequestData

Struct ListOffsetsRequestData 

pub struct ListOffsetsRequestData {
    pub replica_id: i32,
    pub isolation_level: i8,
    pub topics: Vec<ListOffsetsTopic>,
    pub timeout_ms: i32,
    pub _unknown_tagged_fields: Vec<RawTaggedField>,
}

Fields

replica_id: i32

The broker ID of the requester, or -1 if this request is being made by a normal consumer.

isolation_level: i8

This setting controls the visibility of transactional records. Using READ_UNCOMMITTED (isolation_level = 0) makes all records visible. With READ_COMMITTED (isolation_level = 1), non-transactional and COMMITTED transactional records are visible. To be more concrete, READ_COMMITTED returns all data from offsets smaller than the current LSO (last stable offset), and enables the inclusion of the list of aborted transactions in the result, which allows consumers to discard ABORTED transactional records.

topics: Vec<ListOffsetsTopic>

Each topic in the request.

timeout_ms: i32

The timeout to await a response in milliseconds for requests that require reading from remote storage for topics enabled with tiered storage.

_unknown_tagged_fields: Vec<RawTaggedField>

Implementations

Source

impl ListOffsetsRequestData

pub fn with_replica_id(self, value: i32) -> Self

pub fn with_isolation_level(self, value: i8) -> Self

pub fn with_topics(self, value: Vec<ListOffsetsTopic>) -> Self

pub fn with_timeout_ms(self, value: i32) -> Self

pub fn read(buf: &mut Bytes, version: i16) -> Result<Self>

pub fn write(&self, buf: &mut BytesMut, version: i16) -> Result<()>

pub fn encoded_len(&self, version: i16) -> Result<usize>