pub struct ListPartitionReassignmentsRequestData {
pub timeout_ms: i32,
pub topics: Option<Vec<ListPartitionReassignmentsTopics>>,
pub _unknown_tagged_fields: Vec<RawTaggedField>,
}Fields
timeout_ms: i32The time in ms to wait for the request to complete.
topics: Option<Vec<ListPartitionReassignmentsTopics>>The topics to list partition reassignments for, or null to list everything.
_unknown_tagged_fields: Vec<RawTaggedField>Implementations
Sourceimpl ListPartitionReassignmentsRequestData
impl ListPartitionReassignmentsRequestData
pub fn with_timeout_ms(self, value: i32) -> Self
pub fn with_topics( self, value: Option<Vec<ListPartitionReassignmentsTopics>>, ) -> Self
pub fn read(buf: &mut Bytes, version: i16) -> Result<Self>
pub fn write(&self, buf: &mut BytesMut, version: i16) -> Result<()>
pub fn encoded_len(&self, version: i16) -> Result<usize>