pub struct ListTransactionsResponseData {
pub throttle_time_ms: i32,
pub error_code: i16,
pub unknown_state_filters: Vec<KafkaString>,
pub transaction_states: Vec<TransactionState>,
pub _unknown_tagged_fields: Vec<RawTaggedField>,
}Fields
throttle_time_ms: i32The duration in milliseconds for which the request was throttled due to a quota violation, or zero if the request did not violate any quota.
error_code: i16The error code, or 0 if there was no error.
unknown_state_filters: Vec<KafkaString>Set of state filters provided in the request which were unknown to the transaction coordinator.
transaction_states: Vec<TransactionState>The current state of the transaction for the transactional id.
_unknown_tagged_fields: Vec<RawTaggedField>Implementations
Sourceimpl ListTransactionsResponseData
impl ListTransactionsResponseData
pub fn with_throttle_time_ms(self, value: i32) -> Self
pub fn with_error_code(self, value: i16) -> Self
pub fn with_unknown_state_filters(self, value: Vec<KafkaString>) -> Self
pub fn with_transaction_states(self, value: Vec<TransactionState>) -> Self
pub fn read(buf: &mut Bytes, version: i16) -> Result<Self>
pub fn write(&self, buf: &mut BytesMut, version: i16) -> Result<()>
pub fn encoded_len(&self, version: i16) -> Result<usize>