pub struct MetadataRequestData {
pub topics: Option<Vec<MetadataRequestTopic>>,
pub allow_auto_topic_creation: bool,
pub include_cluster_authorized_operations: bool,
pub include_topic_authorized_operations: bool,
pub _unknown_tagged_fields: Vec<RawTaggedField>,
}Fields
topics: Option<Vec<MetadataRequestTopic>>The topics to fetch metadata for.
allow_auto_topic_creation: boolIf this is true, the broker may auto-create topics that we requested which do not already exist, if it is configured to do so.
Whether to include cluster authorized operations.
Whether to include topic authorized operations.
_unknown_tagged_fields: Vec<RawTaggedField>Implementations
Sourceimpl MetadataRequestData
impl MetadataRequestData
pub fn with_topics(self, value: Option<Vec<MetadataRequestTopic>>) -> Self
pub fn with_allow_auto_topic_creation(self, value: bool) -> Self
pub fn read(buf: &mut Bytes, version: i16) -> Result<Self>
pub fn write(&self, buf: &mut BytesMut, version: i16) -> Result<()>
pub fn encoded_len(&self, version: i16) -> Result<usize>