pub struct MetadataResponseData {
pub throttle_time_ms: i32,
pub brokers: Vec<MetadataResponseBroker>,
pub cluster_id: Option<KafkaString>,
pub controller_id: i32,
pub topics: Vec<MetadataResponseTopic>,
pub cluster_authorized_operations: i32,
pub error_code: i16,
pub _unknown_tagged_fields: Vec<RawTaggedField>,
}Fields
throttle_time_ms: i32The duration in milliseconds for which the request was throttled due to a quota violation, or zero if the request did not violate any quota.
brokers: Vec<MetadataResponseBroker>A list of brokers present in the cluster.
cluster_id: Option<KafkaString>The cluster ID that responding broker belongs to.
controller_id: i32The ID of the controller broker.
topics: Vec<MetadataResponseTopic>Each topic in the response.
32-bit bitfield to represent authorized operations for this cluster.
error_code: i16The top-level error code, or 0 if there was no error.
_unknown_tagged_fields: Vec<RawTaggedField>Implementations
Sourceimpl MetadataResponseData
impl MetadataResponseData
pub fn with_throttle_time_ms(self, value: i32) -> Self
pub fn with_brokers(self, value: Vec<MetadataResponseBroker>) -> Self
pub fn with_cluster_id(self, value: Option<KafkaString>) -> Self
pub fn with_controller_id(self, value: i32) -> Self
pub fn with_topics(self, value: Vec<MetadataResponseTopic>) -> Self
pub fn with_error_code(self, value: i16) -> Self
pub fn read(buf: &mut Bytes, version: i16) -> Result<Self>
pub fn write(&self, buf: &mut BytesMut, version: i16) -> Result<()>
pub fn encoded_len(&self, version: i16) -> Result<usize>