OffsetCommitRequestData

Struct OffsetCommitRequestData 

pub struct OffsetCommitRequestData {
    pub group_id: KafkaString,
    pub generation_id_or_member_epoch: i32,
    pub member_id: KafkaString,
    pub group_instance_id: Option<KafkaString>,
    pub retention_time_ms: i64,
    pub topics: Vec<OffsetCommitRequestTopic>,
    pub _unknown_tagged_fields: Vec<RawTaggedField>,
}

Fields

group_id: KafkaString

The unique group identifier.

generation_id_or_member_epoch: i32

The generation of the group if using the classic group protocol or the member epoch if using the consumer protocol.

member_id: KafkaString

The member ID assigned by the group coordinator.

group_instance_id: Option<KafkaString>

The unique identifier of the consumer instance provided by end user.

retention_time_ms: i64

The time period in ms to retain the offset.

topics: Vec<OffsetCommitRequestTopic>

The topics to commit offsets for.

_unknown_tagged_fields: Vec<RawTaggedField>

Implementations

Source

impl OffsetCommitRequestData

pub fn with_group_id(self, value: KafkaString) -> Self

pub fn with_generation_id_or_member_epoch(self, value: i32) -> Self

pub fn with_member_id(self, value: KafkaString) -> Self

pub fn with_group_instance_id(self, value: Option<KafkaString>) -> Self

pub fn with_retention_time_ms(self, value: i64) -> Self

pub fn with_topics(self, value: Vec<OffsetCommitRequestTopic>) -> Self

pub fn read(buf: &mut Bytes, version: i16) -> Result<Self>

pub fn write(&self, buf: &mut BytesMut, version: i16) -> Result<()>

pub fn encoded_len(&self, version: i16) -> Result<usize>