pub struct OffsetDeleteResponseData {
pub error_code: i16,
pub throttle_time_ms: i32,
pub topics: Vec<OffsetDeleteResponseTopic>,
pub _unknown_tagged_fields: Vec<RawTaggedField>,
}Fields
error_code: i16The top-level error code, or 0 if there was no error.
throttle_time_ms: i32The duration in milliseconds for which the request was throttled due to a quota violation, or zero if the request did not violate any quota.
topics: Vec<OffsetDeleteResponseTopic>The responses for each topic.
_unknown_tagged_fields: Vec<RawTaggedField>Implementations
Sourceimpl OffsetDeleteResponseData
impl OffsetDeleteResponseData
pub fn with_error_code(self, value: i16) -> Self
pub fn with_throttle_time_ms(self, value: i32) -> Self
pub fn with_topics(self, value: Vec<OffsetDeleteResponseTopic>) -> Self
pub fn read(buf: &mut Bytes, version: i16) -> Result<Self>
pub fn write(&self, buf: &mut BytesMut, version: i16) -> Result<()>
pub fn encoded_len(&self, version: i16) -> Result<usize>