pub struct OffsetForLeaderPartition {
pub partition: i32,
pub current_leader_epoch: i32,
pub leader_epoch: i32,
pub _unknown_tagged_fields: Vec<RawTaggedField>,
}Fields
partition: i32The partition index.
current_leader_epoch: i32An epoch used to fence consumers/replicas with old metadata. If the epoch provided by the client is larger than the current epoch known to the broker, then the UNKNOWN_LEADER_EPOCH error code will be returned. If the provided epoch is smaller, then the FENCED_LEADER_EPOCH error code will be returned.
leader_epoch: i32The epoch to look up an offset for.
_unknown_tagged_fields: Vec<RawTaggedField>Implementations
Sourceimpl OffsetForLeaderPartition
impl OffsetForLeaderPartition
pub fn with_partition(self, value: i32) -> Self
pub fn with_current_leader_epoch(self, value: i32) -> Self
pub fn with_leader_epoch(self, value: i32) -> Self
pub fn read(buf: &mut Bytes, version: i16) -> Result<Self>
pub fn write(&self, buf: &mut BytesMut, version: i16) -> Result<()>
pub fn encoded_len(&self, version: i16) -> Result<usize>