pub struct BatchIndexAndErrorMessage {
pub batch_index: i32,
pub batch_index_error_message: Option<KafkaString>,
pub _unknown_tagged_fields: Vec<RawTaggedField>,
}Fields
batch_index: i32The batch index of the record that caused the batch to be dropped.
batch_index_error_message: Option<KafkaString>The error message of the record that caused the batch to be dropped.
_unknown_tagged_fields: Vec<RawTaggedField>Implementations
Sourceimpl BatchIndexAndErrorMessage
impl BatchIndexAndErrorMessage
pub fn with_batch_index(self, value: i32) -> Self
pub fn with_batch_index_error_message(self, value: Option<KafkaString>) -> Self
pub fn read(buf: &mut Bytes, version: i16) -> Result<Self>
pub fn write(&self, buf: &mut BytesMut, version: i16) -> Result<()>
pub fn encoded_len(&self, version: i16) -> Result<usize>