pub struct PartitionProduceResponse {
pub index: i32,
pub error_code: i16,
pub base_offset: i64,
pub log_append_time_ms: i64,
pub log_start_offset: i64,
pub record_errors: Vec<BatchIndexAndErrorMessage>,
pub error_message: Option<KafkaString>,
pub current_leader: LeaderIdAndEpoch,
pub _unknown_tagged_fields: Vec<RawTaggedField>,
}Fields
index: i32The partition index.
error_code: i16The error code, or 0 if there was no error.
base_offset: i64The base offset.
log_append_time_ms: i64The timestamp returned by broker after appending the messages. If CreateTime is used for the topic, the timestamp will be -1. If LogAppendTime is used for the topic, the timestamp will be the broker local time when the messages are appended.
log_start_offset: i64The log start offset.
record_errors: Vec<BatchIndexAndErrorMessage>The batch indices of records that caused the batch to be dropped.
error_message: Option<KafkaString>The global error message summarizing the common root cause of the records that caused the batch to be dropped.
current_leader: LeaderIdAndEpochThe leader broker that the producer should use for future requests.
_unknown_tagged_fields: Vec<RawTaggedField>Implementations
Sourceimpl PartitionProduceResponse
impl PartitionProduceResponse
pub fn with_index(self, value: i32) -> Self
pub fn with_error_code(self, value: i16) -> Self
pub fn with_base_offset(self, value: i64) -> Self
pub fn with_log_append_time_ms(self, value: i64) -> Self
pub fn with_log_start_offset(self, value: i64) -> Self
pub fn with_record_errors(self, value: Vec<BatchIndexAndErrorMessage>) -> Self
pub fn with_error_message(self, value: Option<KafkaString>) -> Self
pub fn with_current_leader(self, value: LeaderIdAndEpoch) -> Self
pub fn read(buf: &mut Bytes, version: i16) -> Result<Self>
pub fn write(&self, buf: &mut BytesMut, version: i16) -> Result<()>
pub fn encoded_len(&self, version: i16) -> Result<usize>