pub struct SaslAuthenticateResponseData {
pub error_code: i16,
pub error_message: Option<KafkaString>,
pub auth_bytes: Bytes,
pub session_lifetime_ms: i64,
pub _unknown_tagged_fields: Vec<RawTaggedField>,
}Fields
error_code: i16The error code, or 0 if there was no error.
error_message: Option<KafkaString>The error message, or null if there was no error.
auth_bytes: BytesThe SASL authentication bytes from the server, as defined by the SASL mechanism.
session_lifetime_ms: i64Number of milliseconds after which only re-authentication over the existing connection to create a new session can occur.
_unknown_tagged_fields: Vec<RawTaggedField>Implementations
Sourceimpl SaslAuthenticateResponseData
impl SaslAuthenticateResponseData
pub fn with_error_code(self, value: i16) -> Self
pub fn with_error_message(self, value: Option<KafkaString>) -> Self
pub fn with_auth_bytes(self, value: Bytes) -> Self
pub fn with_session_lifetime_ms(self, value: i64) -> Self
pub fn read(buf: &mut Bytes, version: i16) -> Result<Self>
pub fn write(&self, buf: &mut BytesMut, version: i16) -> Result<()>
pub fn encoded_len(&self, version: i16) -> Result<usize>