pub struct AcquiredRecords {
pub first_offset: i64,
pub last_offset: i64,
pub delivery_count: i16,
pub _unknown_tagged_fields: Vec<RawTaggedField>,
}Fields
first_offset: i64The earliest offset in this batch of acquired records.
last_offset: i64The last offset of this batch of acquired records.
delivery_count: i16The delivery count of this batch of acquired records.
_unknown_tagged_fields: Vec<RawTaggedField>Implementations
Sourceimpl AcquiredRecords
impl AcquiredRecords
pub fn with_first_offset(self, value: i64) -> Self
pub fn with_last_offset(self, value: i64) -> Self
pub fn with_delivery_count(self, value: i16) -> Self
pub fn read(buf: &mut Bytes, _version: i16) -> Result<Self>
pub fn write(&self, buf: &mut BytesMut, _version: i16) -> Result<()>
pub fn encoded_len(&self, _version: i16) -> Result<usize>