ShareFetchResponseData

Struct ShareFetchResponseData 

pub struct ShareFetchResponseData {
    pub throttle_time_ms: i32,
    pub error_code: i16,
    pub error_message: Option<KafkaString>,
    pub acquisition_lock_timeout_ms: i32,
    pub responses: Vec<ShareFetchableTopicResponse>,
    pub node_endpoints: Vec<NodeEndpoint>,
    pub _unknown_tagged_fields: Vec<RawTaggedField>,
}

Fields

throttle_time_ms: i32

The duration in milliseconds for which the request was throttled due to a quota violation, or zero if the request did not violate any quota.

error_code: i16

The top-level response error code.

error_message: Option<KafkaString>

The top-level error message, or null if there was no error.

acquisition_lock_timeout_ms: i32

The time in milliseconds for which the acquired records are locked.

responses: Vec<ShareFetchableTopicResponse>

The response topics.

node_endpoints: Vec<NodeEndpoint>

Endpoints for all current leaders enumerated in PartitionData with error NOT_LEADER_OR_FOLLOWER.

_unknown_tagged_fields: Vec<RawTaggedField>

Implementations

Source

impl ShareFetchResponseData

pub fn with_throttle_time_ms(self, value: i32) -> Self

pub fn with_error_code(self, value: i16) -> Self

pub fn with_error_message(self, value: Option<KafkaString>) -> Self

pub fn with_acquisition_lock_timeout_ms(self, value: i32) -> Self

pub fn with_responses(self, value: Vec<ShareFetchableTopicResponse>) -> Self

pub fn with_node_endpoints(self, value: Vec<NodeEndpoint>) -> Self

pub fn read(buf: &mut Bytes, version: i16) -> Result<Self>

pub fn write(&self, buf: &mut BytesMut, version: i16) -> Result<()>

pub fn encoded_len(&self, version: i16) -> Result<usize>