StreamsGroupHeartbeatRequestData

Struct StreamsGroupHeartbeatRequestData 

pub struct StreamsGroupHeartbeatRequestData {
Show 18 fields pub group_id: KafkaString, pub member_id: KafkaString, pub member_epoch: i32, pub endpoint_information_epoch: i32, pub instance_id: Option<KafkaString>, pub rack_id: Option<KafkaString>, pub rebalance_timeout_ms: i32, pub topology: Option<Box<Topology>>, pub active_tasks: Option<Vec<TaskIds>>, pub standby_tasks: Option<Vec<TaskIds>>, pub warmup_tasks: Option<Vec<TaskIds>>, pub process_id: Option<KafkaString>, pub user_endpoint: Option<Box<Endpoint>>, pub client_tags: Option<Vec<KeyValue>>, pub task_offsets: Option<Vec<TaskOffset>>, pub task_end_offsets: Option<Vec<TaskOffset>>, pub shutdown_application: bool, pub _unknown_tagged_fields: Vec<RawTaggedField>,
}

Fields

group_id: KafkaString

The group identifier.

member_id: KafkaString

The member ID generated by the streams consumer. The member ID must be kept during the entire lifetime of the streams consumer process.

member_epoch: i32

The current member epoch; 0 to join the group; -1 to leave the group; -2 to indicate that the static member will rejoin.

endpoint_information_epoch: i32

The current endpoint epoch of this client, represents the latest endpoint epoch this client received

instance_id: Option<KafkaString>

null if not provided or if it didn’t change since the last heartbeat; the instance ID for static membership otherwise.

rack_id: Option<KafkaString>

null if not provided or if it didn’t change since the last heartbeat; the rack ID of the member otherwise.

rebalance_timeout_ms: i32

-1 if it didn’t change since the last heartbeat; the maximum time in milliseconds that the coordinator will wait on the member to revoke its tasks otherwise.

topology: Option<Box<Topology>>

The topology metadata of the streams application. Used to initialize the topology of the group and to check if the topology corresponds to the topology initialized for the group. Only sent when memberEpoch = 0, must be non-empty. Null otherwise.

active_tasks: Option<Vec<TaskIds>>

Currently owned active tasks for this client. Null if unchanged since last heartbeat.

standby_tasks: Option<Vec<TaskIds>>

Currently owned standby tasks for this client. Null if unchanged since last heartbeat.

warmup_tasks: Option<Vec<TaskIds>>

Currently owned warm-up tasks for this client. Null if unchanged since last heartbeat.

process_id: Option<KafkaString>

Identity of the streams instance that may have multiple consumers. Null if unchanged since last heartbeat.

user_endpoint: Option<Box<Endpoint>>

User-defined endpoint for Interactive Queries. Null if unchanged since last heartbeat, or if not defined on the client.

client_tags: Option<Vec<KeyValue>>

Used for rack-aware assignment algorithm. Null if unchanged since last heartbeat.

task_offsets: Option<Vec<TaskOffset>>

Cumulative changelog offsets for tasks. Only updated when a warm-up task has caught up, and according to the task offset interval. Null if unchanged since last heartbeat.

task_end_offsets: Option<Vec<TaskOffset>>

Cumulative changelog end-offsets for tasks. Only updated when a warm-up task has caught up, and according to the task offset interval. Null if unchanged since last heartbeat.

shutdown_application: bool

Whether all Streams clients in the group should shut down.

_unknown_tagged_fields: Vec<RawTaggedField>

Implementations

Source

impl StreamsGroupHeartbeatRequestData

pub fn with_group_id(self, value: KafkaString) -> Self

pub fn with_member_id(self, value: KafkaString) -> Self

pub fn with_member_epoch(self, value: i32) -> Self

pub fn with_endpoint_information_epoch(self, value: i32) -> Self

pub fn with_instance_id(self, value: Option<KafkaString>) -> Self

pub fn with_rack_id(self, value: Option<KafkaString>) -> Self

pub fn with_rebalance_timeout_ms(self, value: i32) -> Self

pub fn with_topology(self, value: Option<Box<Topology>>) -> Self

pub fn with_active_tasks(self, value: Option<Vec<TaskIds>>) -> Self

pub fn with_standby_tasks(self, value: Option<Vec<TaskIds>>) -> Self

pub fn with_warmup_tasks(self, value: Option<Vec<TaskIds>>) -> Self

pub fn with_process_id(self, value: Option<KafkaString>) -> Self

pub fn with_user_endpoint(self, value: Option<Box<Endpoint>>) -> Self

pub fn with_client_tags(self, value: Option<Vec<KeyValue>>) -> Self

pub fn with_task_offsets(self, value: Option<Vec<TaskOffset>>) -> Self

pub fn with_task_end_offsets(self, value: Option<Vec<TaskOffset>>) -> Self

pub fn with_shutdown_application(self, value: bool) -> Self

pub fn read(buf: &mut Bytes, version: i16) -> Result<Self>

pub fn write(&self, buf: &mut BytesMut, version: i16) -> Result<()>

pub fn encoded_len(&self, version: i16) -> Result<usize>