pub struct EndpointToPartitions {
pub user_endpoint: Endpoint,
pub active_partitions: Vec<TopicPartition>,
pub standby_partitions: Vec<TopicPartition>,
pub _unknown_tagged_fields: Vec<RawTaggedField>,
}Fields
user_endpoint: EndpointUser-defined endpoint to connect to the node
active_partitions: Vec<TopicPartition>All topic partitions materialized by active tasks on the node
standby_partitions: Vec<TopicPartition>All topic partitions materialized by standby tasks on the node
_unknown_tagged_fields: Vec<RawTaggedField>Implementations
Sourceimpl EndpointToPartitions
impl EndpointToPartitions
pub fn with_user_endpoint(self, value: Endpoint) -> Self
pub fn with_active_partitions(self, value: Vec<TopicPartition>) -> Self
pub fn with_standby_partitions(self, value: Vec<TopicPartition>) -> Self
pub fn read(buf: &mut Bytes, version: i16) -> Result<Self>
pub fn write(&self, buf: &mut BytesMut, version: i16) -> Result<()>
pub fn encoded_len(&self, version: i16) -> Result<usize>