StreamsGroupHeartbeatResponseData

Struct StreamsGroupHeartbeatResponseData 

pub struct StreamsGroupHeartbeatResponseData {
Show 15 fields pub throttle_time_ms: i32, pub error_code: i16, pub error_message: Option<KafkaString>, pub member_id: KafkaString, pub member_epoch: i32, pub heartbeat_interval_ms: i32, pub acceptable_recovery_lag: i32, pub task_offset_interval_ms: i32, pub status: Option<Vec<Status>>, pub active_tasks: Option<Vec<TaskIds>>, pub standby_tasks: Option<Vec<TaskIds>>, pub warmup_tasks: Option<Vec<TaskIds>>, pub endpoint_information_epoch: i32, pub partitions_by_user_endpoint: Option<Vec<EndpointToPartitions>>, pub _unknown_tagged_fields: Vec<RawTaggedField>,
}

Fields

throttle_time_ms: i32

The duration in milliseconds for which the request was throttled due to a quota violation, or zero if the request did not violate any quota.

error_code: i16

The top-level error code, or 0 if there was no error

error_message: Option<KafkaString>

The top-level error message, or null if there was no error.

member_id: KafkaString

The member id is always generated by the streams consumer.

member_epoch: i32

The member epoch.

heartbeat_interval_ms: i32

The heartbeat interval in milliseconds.

acceptable_recovery_lag: i32

The maximal lag a warm-up task can have to be considered caught-up.

task_offset_interval_ms: i32

The interval in which the task changelog offsets on a client are updated on the broker. The offsets are sent with the next heartbeat after this time has passed.

status: Option<Vec<Status>>

Indicate zero or more status for the group.

active_tasks: Option<Vec<TaskIds>>

Assigned active tasks for this client. Null if unchanged since last heartbeat.

standby_tasks: Option<Vec<TaskIds>>

Assigned standby tasks for this client. Null if unchanged since last heartbeat.

warmup_tasks: Option<Vec<TaskIds>>

Assigned warm-up tasks for this client. Null if unchanged since last heartbeat.

endpoint_information_epoch: i32

The endpoint epoch set in the response

partitions_by_user_endpoint: Option<Vec<EndpointToPartitions>>

Global assignment information used for IQ. Null if unchanged since last heartbeat.

_unknown_tagged_fields: Vec<RawTaggedField>

Implementations

Source

impl StreamsGroupHeartbeatResponseData

pub fn with_throttle_time_ms(self, value: i32) -> Self

pub fn with_error_code(self, value: i16) -> Self

pub fn with_error_message(self, value: Option<KafkaString>) -> Self

pub fn with_member_id(self, value: KafkaString) -> Self

pub fn with_member_epoch(self, value: i32) -> Self

pub fn with_heartbeat_interval_ms(self, value: i32) -> Self

pub fn with_acceptable_recovery_lag(self, value: i32) -> Self

pub fn with_task_offset_interval_ms(self, value: i32) -> Self

pub fn with_status(self, value: Option<Vec<Status>>) -> Self

pub fn with_active_tasks(self, value: Option<Vec<TaskIds>>) -> Self

pub fn with_standby_tasks(self, value: Option<Vec<TaskIds>>) -> Self

pub fn with_warmup_tasks(self, value: Option<Vec<TaskIds>>) -> Self

pub fn with_endpoint_information_epoch(self, value: i32) -> Self

pub fn with_partitions_by_user_endpoint( self, value: Option<Vec<EndpointToPartitions>>, ) -> Self

pub fn read(buf: &mut Bytes, version: i16) -> Result<Self>

pub fn write(&self, buf: &mut BytesMut, version: i16) -> Result<()>

pub fn encoded_len(&self, version: i16) -> Result<usize>