pub struct SyncGroupResponseData {
pub throttle_time_ms: i32,
pub error_code: i16,
pub protocol_type: Option<KafkaString>,
pub protocol_name: Option<KafkaString>,
pub assignment: Bytes,
pub _unknown_tagged_fields: Vec<RawTaggedField>,
}Fields
throttle_time_ms: i32The duration in milliseconds for which the request was throttled due to a quota violation, or zero if the request did not violate any quota.
error_code: i16The error code, or 0 if there was no error.
protocol_type: Option<KafkaString>The group protocol type.
protocol_name: Option<KafkaString>The group protocol name.
assignment: BytesThe member assignment.
_unknown_tagged_fields: Vec<RawTaggedField>Implementations
Sourceimpl SyncGroupResponseData
impl SyncGroupResponseData
pub fn with_throttle_time_ms(self, value: i32) -> Self
pub fn with_error_code(self, value: i16) -> Self
pub fn with_protocol_type(self, value: Option<KafkaString>) -> Self
pub fn with_protocol_name(self, value: Option<KafkaString>) -> Self
pub fn with_assignment(self, value: Bytes) -> Self
pub fn read(buf: &mut Bytes, version: i16) -> Result<Self>
pub fn write(&self, buf: &mut BytesMut, version: i16) -> Result<()>
pub fn encoded_len(&self, version: i16) -> Result<usize>