TxnOffsetCommitRequestData

Struct TxnOffsetCommitRequestData 

pub struct TxnOffsetCommitRequestData {
    pub transactional_id: KafkaString,
    pub group_id: KafkaString,
    pub producer_id: i64,
    pub producer_epoch: i16,
    pub generation_id: i32,
    pub member_id: KafkaString,
    pub group_instance_id: Option<KafkaString>,
    pub topics: Vec<TxnOffsetCommitRequestTopic>,
    pub _unknown_tagged_fields: Vec<RawTaggedField>,
}

Fields

transactional_id: KafkaString

The ID of the transaction.

group_id: KafkaString

The ID of the group.

producer_id: i64

The current producer ID in use by the transactional ID.

producer_epoch: i16

The current epoch associated with the producer ID.

generation_id: i32

The generation of the consumer.

member_id: KafkaString

The member ID assigned by the group coordinator.

group_instance_id: Option<KafkaString>

The unique identifier of the consumer instance provided by end user.

topics: Vec<TxnOffsetCommitRequestTopic>

Each topic that we want to commit offsets for.

_unknown_tagged_fields: Vec<RawTaggedField>

Implementations

Source

impl TxnOffsetCommitRequestData

pub fn with_transactional_id(self, value: KafkaString) -> Self

pub fn with_group_id(self, value: KafkaString) -> Self

pub fn with_producer_id(self, value: i64) -> Self

pub fn with_producer_epoch(self, value: i16) -> Self

pub fn with_generation_id(self, value: i32) -> Self

pub fn with_member_id(self, value: KafkaString) -> Self

pub fn with_group_instance_id(self, value: Option<KafkaString>) -> Self

pub fn with_topics(self, value: Vec<TxnOffsetCommitRequestTopic>) -> Self

pub fn read(buf: &mut Bytes, version: i16) -> Result<Self>

pub fn write(&self, buf: &mut BytesMut, version: i16) -> Result<()>

pub fn encoded_len(&self, version: i16) -> Result<usize>