pub struct TxnOffsetCommitResponseData {
pub throttle_time_ms: i32,
pub topics: Vec<TxnOffsetCommitResponseTopic>,
pub _unknown_tagged_fields: Vec<RawTaggedField>,
}Fields
throttle_time_ms: i32The duration in milliseconds for which the request was throttled due to a quota violation, or zero if the request did not violate any quota.
topics: Vec<TxnOffsetCommitResponseTopic>The responses for each topic.
_unknown_tagged_fields: Vec<RawTaggedField>Implementations
Sourceimpl TxnOffsetCommitResponseData
impl TxnOffsetCommitResponseData
pub fn with_throttle_time_ms(self, value: i32) -> Self
pub fn with_topics(self, value: Vec<TxnOffsetCommitResponseTopic>) -> Self
pub fn read(buf: &mut Bytes, version: i16) -> Result<Self>
pub fn write(&self, buf: &mut BytesMut, version: i16) -> Result<()>
pub fn encoded_len(&self, version: i16) -> Result<usize>