pub struct FeatureUpdateKey {
pub feature: KafkaString,
pub max_version_level: i16,
pub allow_downgrade: bool,
pub upgrade_type: i8,
pub _unknown_tagged_fields: Vec<RawTaggedField>,
}Fields
feature: KafkaStringThe name of the finalized feature to be updated.
max_version_level: i16The new maximum version level for the finalized feature. A value >= 1 is valid. A value < 1, is special, and can be used to request the deletion of the finalized feature.
allow_downgrade: boolDEPRECATED in version 1 (see DowngradeType). When set to true, the finalized feature version level is allowed to be downgraded/deleted. The downgrade request will fail if the new maximum version level is a value that’s not lower than the existing maximum finalized version level.
upgrade_type: i8Determine which type of upgrade will be performed: 1 will perform an upgrade only (default), 2 is safe downgrades only (lossless), 3 is unsafe downgrades (lossy).
_unknown_tagged_fields: Vec<RawTaggedField>Implementations
Sourceimpl FeatureUpdateKey
impl FeatureUpdateKey
pub fn with_feature(self, value: KafkaString) -> Self
pub fn with_max_version_level(self, value: i16) -> Self
pub fn with_allow_downgrade(self, value: bool) -> Self
pub fn with_upgrade_type(self, value: i8) -> Self
pub fn read(buf: &mut Bytes, version: i16) -> Result<Self>
pub fn write(&self, buf: &mut BytesMut, version: i16) -> Result<()>
pub fn encoded_len(&self, version: i16) -> Result<usize>