pub struct UpdateFeaturesRequestData {
pub timeout_ms: i32,
pub feature_updates: Vec<FeatureUpdateKey>,
pub validate_only: bool,
pub _unknown_tagged_fields: Vec<RawTaggedField>,
}Fields
timeout_ms: i32How long to wait in milliseconds before timing out the request.
feature_updates: Vec<FeatureUpdateKey>The list of updates to finalized features.
validate_only: boolTrue if we should validate the request, but not perform the upgrade or downgrade.
_unknown_tagged_fields: Vec<RawTaggedField>Implementations
Sourceimpl UpdateFeaturesRequestData
impl UpdateFeaturesRequestData
pub fn with_timeout_ms(self, value: i32) -> Self
pub fn with_feature_updates(self, value: Vec<FeatureUpdateKey>) -> Self
pub fn with_validate_only(self, value: bool) -> Self
pub fn read(buf: &mut Bytes, version: i16) -> Result<Self>
pub fn write(&self, buf: &mut BytesMut, version: i16) -> Result<()>
pub fn encoded_len(&self, version: i16) -> Result<usize>