pub struct UpdateFeaturesResponseData {
pub throttle_time_ms: i32,
pub error_code: i16,
pub error_message: Option<KafkaString>,
pub results: Vec<UpdatableFeatureResult>,
pub _unknown_tagged_fields: Vec<RawTaggedField>,
}Fields
throttle_time_ms: i32The duration in milliseconds for which the request was throttled due to a quota violation, or zero if the request did not violate any quota.
error_code: i16The top-level error code, or 0 if there was no top-level error.
error_message: Option<KafkaString>The top-level error message, or null if there was no top-level error.
results: Vec<UpdatableFeatureResult>Results for each feature update.
_unknown_tagged_fields: Vec<RawTaggedField>Implementations
Sourceimpl UpdateFeaturesResponseData
impl UpdateFeaturesResponseData
pub fn with_throttle_time_ms(self, value: i32) -> Self
pub fn with_error_code(self, value: i16) -> Self
pub fn with_error_message(self, value: Option<KafkaString>) -> Self
pub fn with_results(self, value: Vec<UpdatableFeatureResult>) -> Self
pub fn read(buf: &mut Bytes, version: i16) -> Result<Self>
pub fn write(&self, buf: &mut BytesMut, version: i16) -> Result<()>
pub fn encoded_len(&self, version: i16) -> Result<usize>