pub struct PartitionData {
pub partition_index: i32,
pub replica_epoch: i32,
pub replica_id: i32,
pub replica_directory_id: KafkaUuid,
pub voter_directory_id: KafkaUuid,
pub last_offset_epoch: i32,
pub last_offset: i64,
pub pre_vote: bool,
pub _unknown_tagged_fields: Vec<RawTaggedField>,
}Fields
partition_index: i32The partition index.
replica_epoch: i32The epoch of the voter sending the request
replica_id: i32The replica id of the voter sending the request
replica_directory_id: KafkaUuidThe directory id of the voter sending the request
voter_directory_id: KafkaUuidThe directory id of the voter receiving the request
last_offset_epoch: i32The epoch of the last record written to the metadata log.
last_offset: i64The log end offset of the metadata log of the voter sending the request.
pre_vote: boolWhether the request is a PreVote request (not persisted) or not.
_unknown_tagged_fields: Vec<RawTaggedField>Implementations
Sourceimpl PartitionData
impl PartitionData
pub fn with_partition_index(self, value: i32) -> Self
pub fn with_replica_epoch(self, value: i32) -> Self
pub fn with_replica_id(self, value: i32) -> Self
pub fn with_replica_directory_id(self, value: KafkaUuid) -> Self
pub fn with_voter_directory_id(self, value: KafkaUuid) -> Self
pub fn with_last_offset_epoch(self, value: i32) -> Self
pub fn with_last_offset(self, value: i64) -> Self
pub fn with_pre_vote(self, value: bool) -> Self
pub fn read(buf: &mut Bytes, version: i16) -> Result<Self>
pub fn write(&self, buf: &mut BytesMut, version: i16) -> Result<()>
pub fn encoded_len(&self, version: i16) -> Result<usize>