pub struct Voter {
pub voter_id: i32,
pub voter_directory_id: KafkaUuid,
pub endpoints: Vec<Endpoint>,
pub k_raft_version_feature: KRaftVersionFeature,
pub _unknown_tagged_fields: Vec<RawTaggedField>,
}Fields
voter_id: i32The replica id of the voter in the topic partition.
voter_directory_id: KafkaUuidThe directory id of the voter in the topic partition.
endpoints: Vec<Endpoint>The endpoint that can be used to communicate with the voter.
k_raft_version_feature: KRaftVersionFeatureThe range of versions of the protocol that the replica supports.
_unknown_tagged_fields: Vec<RawTaggedField>Implementations
Sourceimpl Voter
impl Voter
pub fn with_voter_id(self, value: i32) -> Self
pub fn with_voter_directory_id(self, value: KafkaUuid) -> Self
pub fn with_endpoints(self, value: Vec<Endpoint>) -> Self
pub fn with_k_raft_version_feature(self, value: KRaftVersionFeature) -> Self
pub fn read(buf: &mut Bytes, version: i16) -> Result<Self>
pub fn write(&self, buf: &mut BytesMut, version: i16) -> Result<()>
pub fn encoded_len(&self, version: i16) -> Result<usize>