pub struct PartitionData {
pub partition: i32,
pub state_epoch: i32,
pub leader_epoch: i32,
pub start_offset: i64,
pub delivery_complete_count: i32,
pub state_batches: Vec<StateBatch>,
pub _unknown_tagged_fields: Vec<RawTaggedField>,
}Fields
partition: i32The partition index.
state_epoch: i32The state epoch of the share-partition.
leader_epoch: i32The leader epoch of the share-partition.
start_offset: i64The share-partition start offset, or -1 if the start offset is not being written.
delivery_complete_count: i32The number of offsets greater than or equal to share-partition start offset for which delivery has been completed.
state_batches: Vec<StateBatch>The state batches for the share-partition.
_unknown_tagged_fields: Vec<RawTaggedField>Implementations
Sourceimpl PartitionData
impl PartitionData
pub fn with_partition(self, value: i32) -> Self
pub fn with_state_epoch(self, value: i32) -> Self
pub fn with_leader_epoch(self, value: i32) -> Self
pub fn with_start_offset(self, value: i64) -> Self
pub fn with_delivery_complete_count(self, value: i32) -> Self
pub fn with_state_batches(self, value: Vec<StateBatch>) -> Self
pub fn read(buf: &mut Bytes, version: i16) -> Result<Self>
pub fn write(&self, buf: &mut BytesMut, version: i16) -> Result<()>
pub fn encoded_len(&self, version: i16) -> Result<usize>