WritableTxnMarker

Struct WritableTxnMarker 

pub struct WritableTxnMarker {
    pub producer_id: i64,
    pub producer_epoch: i16,
    pub transaction_result: bool,
    pub topics: Vec<WritableTxnMarkerTopic>,
    pub coordinator_epoch: i32,
    pub transaction_version: i8,
    pub _unknown_tagged_fields: Vec<RawTaggedField>,
}

Fields

producer_id: i64

The current producer ID.

producer_epoch: i16

The current epoch associated with the producer ID.

transaction_result: bool

The result of the transaction to write to the partitions (false = ABORT, true = COMMIT).

topics: Vec<WritableTxnMarkerTopic>

Each topic that we want to write transaction marker(s) for.

coordinator_epoch: i32

Epoch associated with the transaction state partition hosted by this transaction coordinator.

transaction_version: i8

Transaction version of the marker. Ex: 0/1 = legacy (TV0/TV1), 2 = TV2 etc.

_unknown_tagged_fields: Vec<RawTaggedField>

Implementations

Source

impl WritableTxnMarker

pub fn with_producer_id(self, value: i64) -> Self

pub fn with_producer_epoch(self, value: i16) -> Self

pub fn with_transaction_result(self, value: bool) -> Self

pub fn with_topics(self, value: Vec<WritableTxnMarkerTopic>) -> Self

pub fn with_coordinator_epoch(self, value: i32) -> Self

pub fn with_transaction_version(self, value: i8) -> Self

pub fn read(buf: &mut Bytes, version: i16) -> Result<Self>

pub fn write(&self, buf: &mut BytesMut, version: i16) -> Result<()>

pub fn encoded_len(&self, version: i16) -> Result<usize>