#[non_exhaustive]pub enum PrimitiveErrorKind {
InsufficientData {
needed: usize,
available: usize,
},
InvalidVarint {
max_bytes: u8,
},
LengthOutOfRange {
length: u32,
},
}Expand description
Specific reason a primitive read failed.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
InsufficientData
Buffer ran out before the requested width was satisfied.
InvalidVarint
Varint exceeded the maximum allowed byte length (5 for u32, 10 for u64).
LengthOutOfRange
A compact length prefix decoded to a value that overflows i32.