Module record

Module record 

Kafka record batch v2 support.

Record batches are fairly self-contained: RecordBatch::encode computes its own CRC32C and applies any compression chosen via the attributes field; RecordBatch::decode validates the CRC and decompresses before parsing inner records.

Re-exports

pub use self::batch::RecordBatch;
pub use self::batch::TimestampType;
pub use self::batch::decode_batches;
pub use self::batch::decode_next_batch;
pub use self::entry::Record;
pub use self::error::RecordError;
pub use self::error::RecordErrorKind;
pub use self::header::RecordHeader;

Modules

batch
Record-batch v2 container.
entry
Individual records inside a crate::record::RecordBatch.
error
Error types for crate::record.
header
RecordHeader — non-nullable key, nullable value, on a single record.

Constants

MAX_RECORDS_PER_BATCH
Maximum number of records permitted in a single batch.

Type Aliases

Result
Result alias for record-batch operations.