pub struct ApiVersionsResponseData {
pub error_code: i16,
pub api_keys: Vec<ApiVersion>,
pub throttle_time_ms: i32,
pub supported_features: Vec<SupportedFeatureKey>,
pub finalized_features_epoch: i64,
pub finalized_features: Vec<FinalizedFeatureKey>,
pub zk_migration_ready: bool,
pub _unknown_tagged_fields: Vec<RawTaggedField>,
}Fields
error_code: i16The top-level error code.
api_keys: Vec<ApiVersion>The APIs supported by the broker.
throttle_time_ms: i32The duration in milliseconds for which the request was throttled due to a quota violation, or zero if the request did not violate any quota.
supported_features: Vec<SupportedFeatureKey>Features supported by the broker. Note: in v0-v3, features with MinSupportedVersion = 0 are omitted.
finalized_features_epoch: i64The monotonically increasing epoch for the finalized features information. Valid values are
= 0. A value of -1 is special and represents unknown epoch.
finalized_features: Vec<FinalizedFeatureKey>List of cluster-wide finalized features. The information is valid only if FinalizedFeaturesEpoch >= 0.
zk_migration_ready: boolSet by a KRaft controller if the required configurations for ZK migration are present.
_unknown_tagged_fields: Vec<RawTaggedField>Implementations
Sourceimpl ApiVersionsResponseData
impl ApiVersionsResponseData
pub fn with_error_code(self, value: i16) -> Self
pub fn with_api_keys(self, value: Vec<ApiVersion>) -> Self
pub fn with_throttle_time_ms(self, value: i32) -> Self
pub fn with_supported_features(self, value: Vec<SupportedFeatureKey>) -> Self
pub fn with_finalized_features_epoch(self, value: i64) -> Self
pub fn with_finalized_features(self, value: Vec<FinalizedFeatureKey>) -> Self
pub fn with_zk_migration_ready(self, value: bool) -> Self
pub fn read(buf: &mut Bytes, version: i16) -> Result<Self>
pub fn write(&self, buf: &mut BytesMut, version: i16) -> Result<()>
pub fn encoded_len(&self, version: i16) -> Result<usize>