pub struct DescribeClusterResponseData {
pub throttle_time_ms: i32,
pub error_code: i16,
pub error_message: Option<KafkaString>,
pub endpoint_type: i8,
pub cluster_id: KafkaString,
pub controller_id: i32,
pub brokers: Vec<DescribeClusterBroker>,
pub cluster_authorized_operations: i32,
pub _unknown_tagged_fields: Vec<RawTaggedField>,
}Fields
throttle_time_ms: i32The duration in milliseconds for which the request was throttled due to a quota violation, or zero if the request did not violate any quota.
error_code: i16The top-level error code, or 0 if there was no error.
error_message: Option<KafkaString>The top-level error message, or null if there was no error.
endpoint_type: i8The endpoint type that was described. 1=brokers, 2=controllers.
cluster_id: KafkaStringThe cluster ID that responding broker belongs to.
controller_id: i32The ID of the controller. When handled by a controller, returns the current voter leader ID. When handled by a broker, returns a random alive broker ID as a fallback.
brokers: Vec<DescribeClusterBroker>Each broker in the response.
32-bit bitfield to represent authorized operations for this cluster.
_unknown_tagged_fields: Vec<RawTaggedField>Implementations
Sourceimpl DescribeClusterResponseData
impl DescribeClusterResponseData
pub fn with_throttle_time_ms(self, value: i32) -> Self
pub fn with_error_code(self, value: i16) -> Self
pub fn with_error_message(self, value: Option<KafkaString>) -> Self
pub fn with_endpoint_type(self, value: i8) -> Self
pub fn with_cluster_id(self, value: KafkaString) -> Self
pub fn with_controller_id(self, value: i32) -> Self
pub fn with_brokers(self, value: Vec<DescribeClusterBroker>) -> Self
pub fn read(buf: &mut Bytes, version: i16) -> Result<Self>
pub fn write(&self, buf: &mut BytesMut, version: i16) -> Result<()>
pub fn encoded_len(&self, version: i16) -> Result<usize>