pub struct DescribeLogDirsPartition {
pub partition_index: i32,
pub partition_size: i64,
pub offset_lag: i64,
pub is_future_key: bool,
pub _unknown_tagged_fields: Vec<RawTaggedField>,
}Fields
partition_index: i32The partition index.
partition_size: i64The size of the log segments in this partition in bytes.
offset_lag: i64The lag of the log’s LEO w.r.t. partition’s HW (if it is the current log for the partition) or current replica’s LEO (if it is the future log for the partition).
is_future_key: boolTrue if this log is created by AlterReplicaLogDirsRequest and will replace the current log of the replica in the future.
_unknown_tagged_fields: Vec<RawTaggedField>Implementations
Sourceimpl DescribeLogDirsPartition
impl DescribeLogDirsPartition
pub fn with_partition_index(self, value: i32) -> Self
pub fn with_partition_size(self, value: i64) -> Self
pub fn with_offset_lag(self, value: i64) -> Self
pub fn with_is_future_key(self, value: bool) -> Self
pub fn read(buf: &mut Bytes, version: i16) -> Result<Self>
pub fn write(&self, buf: &mut BytesMut, version: i16) -> Result<()>
pub fn encoded_len(&self, version: i16) -> Result<usize>