ErrorCode

Enum ErrorCode 

#[non_exhaustive]
pub enum ErrorCode {
Show 136 variants UnknownServerError, None, OffsetOutOfRange, CorruptMessage, UnknownTopicOrPartition, InvalidFetchSize, LeaderNotAvailable, NotLeaderOrFollower, RequestTimedOut, BrokerNotAvailable, ReplicaNotAvailable, MessageTooLarge, StaleControllerEpoch, OffsetMetadataTooLarge, NetworkException, CoordinatorLoadInProgress, CoordinatorNotAvailable, NotCoordinator, InvalidTopicException, RecordListTooLarge, NotEnoughReplicas, NotEnoughReplicasAfterAppend, InvalidRequiredAcks, IllegalGeneration, InconsistentGroupProtocol, InvalidGroupId, UnknownMemberId, InvalidSessionTimeout, RebalanceInProgress, InvalidCommitOffsetSize, TopicAuthorizationFailed, GroupAuthorizationFailed, ClusterAuthorizationFailed, InvalidTimestamp, UnsupportedSaslMechanism, IllegalSaslState, UnsupportedVersion, TopicAlreadyExists, InvalidPartitions, InvalidReplicationFactor, InvalidReplicaAssignment, InvalidConfig, NotController, InvalidRequest, UnsupportedForMessageFormat, PolicyViolation, OutOfOrderSequenceNumber, DuplicateSequenceNumber, InvalidProducerEpoch, InvalidTxnState, InvalidProducerIdMapping, InvalidTransactionTimeout, ConcurrentTransactions, TransactionCoordinatorFenced, TransactionalIdAuthorizationFailed, SecurityDisabled, OperationNotAttempted, KafkaStorageError, LogDirNotFound, SaslAuthenticationFailed, UnknownProducerId, ReassignmentInProgress, DelegationTokenAuthDisabled, DelegationTokenNotFound, DelegationTokenOwnerMismatch, DelegationTokenRequestNotAllowed, DelegationTokenAuthorizationFailed, DelegationTokenExpired, InvalidPrincipalType, NonEmptyGroup, GroupIdNotFound, FetchSessionIdNotFound, InvalidFetchSessionEpoch, ListenerNotFound, TopicDeletionDisabled, FencedLeaderEpoch, UnknownLeaderEpoch, UnsupportedCompressionType, StaleBrokerEpoch, OffsetNotAvailable, MemberIdRequired, PreferredLeaderNotAvailable, GroupMaxSizeReached, FencedInstanceId, EligibleLeadersNotAvailable, ElectionNotNeeded, NoReassignmentInProgress, GroupSubscribedToTopic, InvalidRecord, UnstableOffsetCommit, ThrottlingQuotaExceeded, ProducerFenced, ResourceNotFound, DuplicateResource, UnacceptableCredential, InconsistentVoterSet, InvalidUpdateVersion, FeatureUpdateFailed, PrincipalDeserializationFailure, SnapshotNotFound, PositionOutOfRange, UnknownTopicId, DuplicateBrokerRegistration, BrokerIdNotRegistered, InconsistentTopicId, InconsistentClusterId, TransactionalIdNotFound, FetchSessionTopicIdError, IneligibleReplica, NewLeaderElected, OffsetMovedToTieredStorage, FencedMemberEpoch, UnreleasedInstanceId, UnsupportedAssignor, StaleMemberEpoch, MismatchedEndpointType, UnsupportedEndpointType, UnknownControllerId, UnknownSubscriptionId, TelemetryTooLarge, InvalidRegistration, TransactionAbortable, InvalidRecordState, ShareSessionNotFound, InvalidShareSessionEpoch, FencedStateEpoch, InvalidVoterKey, DuplicateVoter, VoterNotFound, InvalidRegularExpression, RebootstrapRequired, StreamsInvalidTopology, StreamsInvalidTopologyEpoch, StreamsTopologyFenced, ShareSessionLimitReached, Unknown(i16),
}
Kafka protocol error code.

Every response in the Kafka protocol carries an i16 error code. This enum provides a typed representation with human-readable messages, retriability classification, and forward-compatible handling of unknown codes.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


UnknownServerError



None



OffsetOutOfRange



CorruptMessage



UnknownTopicOrPartition



InvalidFetchSize



LeaderNotAvailable



NotLeaderOrFollower



RequestTimedOut



BrokerNotAvailable



ReplicaNotAvailable



MessageTooLarge



StaleControllerEpoch



OffsetMetadataTooLarge



NetworkException



CoordinatorLoadInProgress



CoordinatorNotAvailable



NotCoordinator



InvalidTopicException



RecordListTooLarge



NotEnoughReplicas



NotEnoughReplicasAfterAppend



InvalidRequiredAcks



IllegalGeneration



InconsistentGroupProtocol



InvalidGroupId



UnknownMemberId



InvalidSessionTimeout



RebalanceInProgress



InvalidCommitOffsetSize



TopicAuthorizationFailed



GroupAuthorizationFailed



ClusterAuthorizationFailed



InvalidTimestamp



UnsupportedSaslMechanism



IllegalSaslState



UnsupportedVersion



TopicAlreadyExists



InvalidPartitions



InvalidReplicationFactor



InvalidReplicaAssignment



InvalidConfig



NotController



InvalidRequest



UnsupportedForMessageFormat



PolicyViolation



OutOfOrderSequenceNumber



DuplicateSequenceNumber



InvalidProducerEpoch



InvalidTxnState



InvalidProducerIdMapping



InvalidTransactionTimeout



ConcurrentTransactions



TransactionCoordinatorFenced



TransactionalIdAuthorizationFailed



SecurityDisabled



OperationNotAttempted



KafkaStorageError



LogDirNotFound



SaslAuthenticationFailed



UnknownProducerId



ReassignmentInProgress



DelegationTokenAuthDisabled



DelegationTokenNotFound



DelegationTokenOwnerMismatch



DelegationTokenRequestNotAllowed



DelegationTokenAuthorizationFailed



DelegationTokenExpired



InvalidPrincipalType



NonEmptyGroup



GroupIdNotFound



FetchSessionIdNotFound



InvalidFetchSessionEpoch



ListenerNotFound



TopicDeletionDisabled



FencedLeaderEpoch



UnknownLeaderEpoch



UnsupportedCompressionType



StaleBrokerEpoch



OffsetNotAvailable



MemberIdRequired



PreferredLeaderNotAvailable



GroupMaxSizeReached



FencedInstanceId



EligibleLeadersNotAvailable



ElectionNotNeeded



NoReassignmentInProgress



GroupSubscribedToTopic



InvalidRecord



UnstableOffsetCommit



ThrottlingQuotaExceeded



ProducerFenced



ResourceNotFound



DuplicateResource



UnacceptableCredential



InconsistentVoterSet



InvalidUpdateVersion



FeatureUpdateFailed



PrincipalDeserializationFailure



SnapshotNotFound



PositionOutOfRange



UnknownTopicId



DuplicateBrokerRegistration



BrokerIdNotRegistered



InconsistentTopicId



InconsistentClusterId



TransactionalIdNotFound



FetchSessionTopicIdError



IneligibleReplica



NewLeaderElected



OffsetMovedToTieredStorage



FencedMemberEpoch



UnreleasedInstanceId



UnsupportedAssignor



StaleMemberEpoch



MismatchedEndpointType



UnsupportedEndpointType



UnknownControllerId



UnknownSubscriptionId



TelemetryTooLarge



InvalidRegistration



TransactionAbortable



InvalidRecordState



ShareSessionNotFound



InvalidShareSessionEpoch



FencedStateEpoch



InvalidVoterKey



DuplicateVoter



VoterNotFound



InvalidRegularExpression



RebootstrapRequired



StreamsInvalidTopology



StreamsInvalidTopologyEpoch



StreamsTopologyFenced



ShareSessionLimitReached



Unknown(i16)

An error code not recognized by this client version.

Implementations

Source

impl ErrorCode

pub fn code(&self) -> i16

Returns the i16 wire value for this error code.

pub fn is_retriable(&self) -> bool

Returns true if the operation that produced this error can be retried.

The retriable set matches the Kafka Java client’s RetriableException hierarchy. ErrorCode::Unknown is not retriable (matches Java client behaviour).

pub fn is_error(&self) -> bool

Returns true if this represents an error condition.

Only ErrorCode::None (code 0) returns false.