pub struct FetchRequestData {Show 13 fields
pub cluster_id: Option<KafkaString>,
pub replica_id: i32,
pub replica_state: ReplicaState,
pub max_wait_ms: i32,
pub min_bytes: i32,
pub max_bytes: i32,
pub isolation_level: i8,
pub session_id: i32,
pub session_epoch: i32,
pub topics: Vec<FetchTopic>,
pub forgotten_topics_data: Vec<ForgottenTopic>,
pub rack_id: KafkaString,
pub _unknown_tagged_fields: Vec<RawTaggedField>,
}Fields
cluster_id: Option<KafkaString>The clusterId if known. This is used to validate metadata fetches prior to broker registration.
replica_id: i32The broker ID of the follower, of -1 if this request is from a consumer.
replica_state: ReplicaStateThe state of the replica in the follower.
max_wait_ms: i32The maximum time in milliseconds to wait for the response.
min_bytes: i32The minimum bytes to accumulate in the response.
max_bytes: i32The maximum bytes to fetch. See KIP-74 for cases where this limit may not be honored.
isolation_level: i8This setting controls the visibility of transactional records. Using READ_UNCOMMITTED (isolation_level = 0) makes all records visible. With READ_COMMITTED (isolation_level = 1), non-transactional and COMMITTED transactional records are visible. To be more concrete, READ_COMMITTED returns all data from offsets smaller than the current LSO (last stable offset), and enables the inclusion of the list of aborted transactions in the result, which allows consumers to discard ABORTED transactional records.
session_id: i32The fetch session ID.
session_epoch: i32The fetch session epoch, which is used for ordering requests in a session.
topics: Vec<FetchTopic>The topics to fetch.
forgotten_topics_data: Vec<ForgottenTopic>In an incremental fetch request, the partitions to remove.
rack_id: KafkaStringRack ID of the consumer making this request.
_unknown_tagged_fields: Vec<RawTaggedField>Implementations
Sourceimpl FetchRequestData
impl FetchRequestData
pub fn with_cluster_id(self, value: Option<KafkaString>) -> Self
pub fn with_replica_id(self, value: i32) -> Self
pub fn with_replica_state(self, value: ReplicaState) -> Self
pub fn with_max_wait_ms(self, value: i32) -> Self
pub fn with_min_bytes(self, value: i32) -> Self
pub fn with_max_bytes(self, value: i32) -> Self
pub fn with_isolation_level(self, value: i8) -> Self
pub fn with_session_id(self, value: i32) -> Self
pub fn with_session_epoch(self, value: i32) -> Self
pub fn with_topics(self, value: Vec<FetchTopic>) -> Self
pub fn with_forgotten_topics_data(self, value: Vec<ForgottenTopic>) -> Self
pub fn with_rack_id(self, value: KafkaString) -> Self
pub fn read(buf: &mut Bytes, version: i16) -> Result<Self>
pub fn write(&self, buf: &mut BytesMut, version: i16) -> Result<()>
pub fn encoded_len(&self, version: i16) -> Result<usize>