pub struct ListTransactionsRequestData {
pub state_filters: Vec<KafkaString>,
pub producer_id_filters: Vec<i64>,
pub duration_filter: i64,
pub transactional_id_pattern: Option<KafkaString>,
pub _unknown_tagged_fields: Vec<RawTaggedField>,
}Fields
state_filters: Vec<KafkaString>The transaction states to filter by: if empty, all transactions are returned; if non-empty, then only transactions matching one of the filtered states will be returned.
producer_id_filters: Vec<i64>The producerIds to filter by: if empty, all transactions will be returned; if non-empty, only transactions which match one of the filtered producerIds will be returned.
duration_filter: i64Duration (in millis) to filter by: if < 0, all transactions will be returned; otherwise, only transactions running longer than this duration will be returned.
transactional_id_pattern: Option<KafkaString>The transactional ID regular expression pattern to filter by: if it is empty or null, all transactions are returned; Otherwise then only the transactions matching the given regular expression will be returned.
_unknown_tagged_fields: Vec<RawTaggedField>Implementations
Sourceimpl ListTransactionsRequestData
impl ListTransactionsRequestData
pub fn with_state_filters(self, value: Vec<KafkaString>) -> Self
pub fn with_producer_id_filters(self, value: Vec<i64>) -> Self
pub fn with_duration_filter(self, value: i64) -> Self
pub fn with_transactional_id_pattern(self, value: Option<KafkaString>) -> Self
pub fn read(buf: &mut Bytes, version: i16) -> Result<Self>
pub fn write(&self, buf: &mut BytesMut, version: i16) -> Result<()>
pub fn encoded_len(&self, version: i16) -> Result<usize>