pub struct ShareFetchRequestData {Show 13 fields
pub group_id: Option<KafkaString>,
pub member_id: Option<KafkaString>,
pub share_session_epoch: i32,
pub max_wait_ms: i32,
pub min_bytes: i32,
pub max_bytes: i32,
pub max_records: i32,
pub batch_size: i32,
pub share_acquire_mode: i8,
pub is_renew_ack: bool,
pub topics: Vec<FetchTopic>,
pub forgotten_topics_data: Vec<ForgottenTopic>,
pub _unknown_tagged_fields: Vec<RawTaggedField>,
}Fields
group_id: Option<KafkaString>The group identifier.
member_id: Option<KafkaString>The member ID.
The current share session epoch: 0 to open a share session; -1 to close it; otherwise increments for consecutive requests.
max_wait_ms: i32The maximum time in milliseconds to wait for the response.
min_bytes: i32The minimum bytes to accumulate in the response.
max_bytes: i32The maximum bytes to fetch. See KIP-74 for cases where this limit may not be honored.
max_records: i32The maximum number of records to fetch. This limit can be exceeded for alignment of batch boundaries.
batch_size: i32The optimal number of records for batches of acquired records and acknowledgements.
The acquire mode to control the fetch behavior - 0:batch-optimized,1:record-limit.
is_renew_ack: boolWhether Renew type acknowledgements present in AcknowledgementBatches.
topics: Vec<FetchTopic>The topics to fetch.
forgotten_topics_data: Vec<ForgottenTopic>The partitions to remove from this share session.
_unknown_tagged_fields: Vec<RawTaggedField>Implementations
pub fn with_group_id(self, value: Option<KafkaString>) -> Self
pub fn with_member_id(self, value: Option<KafkaString>) -> Self
pub fn with_max_wait_ms(self, value: i32) -> Self
pub fn with_min_bytes(self, value: i32) -> Self
pub fn with_max_bytes(self, value: i32) -> Self
pub fn with_max_records(self, value: i32) -> Self
pub fn with_batch_size(self, value: i32) -> Self
pub fn with_is_renew_ack(self, value: bool) -> Self
pub fn with_topics(self, value: Vec<FetchTopic>) -> Self
pub fn with_forgotten_topics_data(self, value: Vec<ForgottenTopic>) -> Self
pub fn read(buf: &mut Bytes, version: i16) -> Result<Self>
pub fn write(&self, buf: &mut BytesMut, version: i16) -> Result<()>
pub fn encoded_len(&self, version: i16) -> Result<usize>